/**************************************************************************************************|
|* Copyright 2016 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|* - Generic Peripheral Library: A general and functional Interface for the specific Peripheral   *|
|* - Low Level Peripheral Access: Register-Bits Level access Macro, user must take care           *|
|*   of calling procedure and hardware constraints                                                *|
|* - Support Target: HY11P Series                                                                 *|
|**************************************************************************************************/
#include <INT.h>           // Interrupt Config for ADC
#include <CLK.h>           // CLK Cpnfig for ADC

/**************************************************************************************************|
|*                               Peripheral Register Bits field                                   *|
|**************************************************************************************************/
// ADCCN1 //
// Bit-field Struc Test for SDCC
#define ADCCN1_ADGN                      0
#define ADCCN1_ADGN_MSK                 (7 << ADCCN1_ADGN)
#define ADCCN1_ADGN_1DIV4               (0 << ADCCN1_ADGN)
#define ADCCN1_ADGN_1DIV2               (1 << ADCCN1_ADGN)
#define ADCCN1_ADGN_1                   (2 << ADCCN1_ADGN)
#define ADCCN1_ADGN_2                   (3 << ADCCN1_ADGN)
#define ADCCN1_ADGN_4                   (4 << ADCCN1_ADGN)
#define ADCCN1_ADGN_8                   (5 << ADCCN1_ADGN)
#define ADCCN1_ADGN_16                  (6 << ADCCN1_ADGN)

#define ADCCN1_PGAGN                     3
#define ADCCN1_PGAGN_MSK                (3 << ADCCN1_PGAGN)
#define ADCCN1_PGAGN_1                  (0 << ADCCN1_PGAGN)
#define ADCCN1_PGAGN_2                  (1 << ADCCN1_PGAGN)
#define ADCCN1_PGAGN_4                  (2 << ADCCN1_PGAGN)
#define ADCCN1_PGAGN_8                  (3 << ADCCN1_PGAGN)

// Reserved field                       5
// Reserved field_MSK                   1 << Reserved field

// Reserved field                       6
// Reserved field_MSK                   1 << Reserved field

#define ADCCN1_ENADC                     7
#define ADCCN1_ENADC_MSK                (1 << ADCCN1_ENADC)
#define ADCCN1_ENADC_ENABLE             (1 << ADCCN1_ENADC)
#define ADCCN1_ENADC_DISABLE            (0 << ADCCN1_ENADC)

// ADCCN2 //
#define ADCCN2_DCSET                     0
#define ADCCN2_DCSET_MSK                (7 << ADCCN2_DCSET)
#define ADCCN2_DCSET_0                  (0 << ADCCN2_DCSET)
#define ADCCN2_DCSET_P1DIV4             (1 << ADCCN2_DCSET)
#define ADCCN2_DCSET_P1DIV2             (2 << ADCCN2_DCSET)
#define ADCCN2_DCSET_P3DIV4             (3 << ADCCN2_DCSET)
#define ADCCN2_DCSET_00                 (4 << ADCCN2_DCSET)
#define ADCCN2_DCSET_N1DIV4             (5 << ADCCN2_DCSET)
#define ADCCN2_DCSET_N1DIV2             (6 << ADCCN2_DCSET)
#define ADCCN2_DCSET_N3DIV4             (7 << ADCCN2_DCSET)

#define ADCCN2_VREGN                     3
#define ADCCN2_VREGN_MSK                (1 << ADCCN2_VREGN)
#define ADCCN2_VREGN_DIV2               (1 << ADCCN2_VREGN)
#define ADCCN2_VREGN_DIV1               (0 << ADCCN2_VREGN)

#define ADCCN2_VRBUF                     4
#define ADCCN2_VRBUF_MSK                (1 << ADCCN2_VRBUF)
#define ADCCN2_VRBUF_ENABLE             (1 << ADCCN2_VRBUF)
#define ADCCN2_VRBUF_DISABLE            (0 << ADCCN2_VRBUF)

#define ADCCN2_INBUF                     5
#define ADCCN2_INBUF_MSK                (1 << ADCCN2_INBUF)
#define ADCCN2_INBUF_ENABLE             (1 << ADCCN2_INBUF)
#define ADCCN2_INBUF_DISABLE            (0 << ADCCN2_INBUF)

// ADCCN3 //
// Reserved field                       0
// Reserved field_MSK                   0x1f << Reserved field
#define ADCCN3_OSR                       5
#define ADCCN3_OSR_MSK                  (7 << ADCCN3_OSR)
#define ADCCN3_OSR_256                  (0 << ADCCN3_OSR)
#define ADCCN3_OSR_512                  (1 << ADCCN3_OSR)
#define ADCCN3_OSR_1024                 (2 << ADCCN3_OSR)
#define ADCCN3_OSR_2048                 (3 << ADCCN3_OSR)
#define ADCCN3_OSR_4096                 (4 << ADCCN3_OSR)
#define ADCCN3_OSR_8192                 (5 << ADCCN3_OSR)
#define ADCCN3_OSR_16384                (6 << ADCCN3_OSR)
#define ADCCN3_OSR_32768                (7 << ADCCN3_OSR)

// AINET1 //
#define AINET1_OPIS                      0
#define AINET1_OPIS_MSK                 (1 << AINET1_OPIS)
#define AINET1_OPIS_ENABLE              (1 << AINET1_OPIS)
#define AINET1_OPIS_DISABLE             (0 << AINET1_OPIS)

#define AINET1_INIS                      1
#define AINET1_INIS_MSK                 (1 << AINET1_INIS)
#define AINET1_INIS_ENABLE              (1 << AINET1_INIS)
#define AINET1_INIS_DISABLE             (0 << AINET1_INIS)

#define AINET1_INL                       2
#define AINET1_INL_MSK                  (7 << AINET1_INL)
#define AINET1_INL_AI3                  (0 << AINET1_INL)
#define AINET1_INL_AI7                  (1 << AINET1_INL)
#define AINET1_INL_AI5                  (2 << AINET1_INL)
#define AINET1_INL_AI1                  (3 << AINET1_INL)
#define AINET1_INL_OPO                  (4 << AINET1_INL)
#define AINET1_INL_VSS                  (5 << AINET1_INL)
#define AINET1_INL_TPSL0                (6 << AINET1_INL)
#define AINET1_INL_TPSL1                (7 << AINET1_INL)

#define AINET1_INH                       5
#define AINET1_INH_MSK                  (7 << AINET1_INH)
#define AINET1_INH_AI2                  (0 << AINET1_INH)
#define AINET1_INH_AI6                  (1 << AINET1_INH)
#define AINET1_INH_AI4                  (2 << AINET1_INH)
#define AINET1_INH_AI0                  (3 << AINET1_INH)
#define AINET1_INH_HALF_VDDA            (4 << AINET1_INH)
#define AINET1_INH_ADM                  (5 << AINET1_INH)
#define AINET1_INH_TPSH1                (6 << AINET1_INH)
#define AINET1_INH_TPSH0                (7 << AINET1_INH)

// AINET2 //
// Reserved field                        0
// Reserved field_MSK                    1 << Reserved field
#define AINET2_VRL                       1
#define AINET2_VRL_MSK                  (3 << AINET2_VRL)
#define AINET2_VRL_AI5                  (0 << AINET2_VRL)
#define AINET2_VRL_AI9                  (1 << AINET2_VRL)
#define AINET2_VRL_AI3                  (2 << AINET2_VRL)
#define AINET2_VRL_VSS                  (3 << AINET2_VRL)

#define AINET2_INX                       3
#define AINET2_INX_MSK                  (3 << AINET2_INX)
#define AINET2_INX_MODE0                (0 << AINET2_INX)
#define AINET2_INX_MODE1                (1 << AINET2_INX)
#define AINET2_INX_MODE2                (2 << AINET2_INX)
#define AINET2_INX_MODE3                (3 << AINET2_INX)

#define AINET2_VRH                       5
#define AINET2_VRH_MSK                  (3 << AINET2_VRH)
#define AINET2_VRH_AI6                  (0 << AINET2_VRH)
#define AINET2_VRH_AI8                  (1 << AINET2_VRH)
#define AINET2_VRH_AI2                  (2 << AINET2_VRH)
#define AINET2_VRH_ACM                  (3 << AINET2_VRH)

// ADCRL //
// All field

// ADCRM //
// All field

// ADCRH //
// All field

/**************************************************************************************************|
|*                                      Function Level                                            *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function-like Macro:                                                                            |
|    Register Bits field Configuration without function call overhead,                             |
|    user should take care of detail of h/w behavior and constrains.                               |
|-------------------------------------------------------------------------------------------------*/
#define ADC_CLK_Enable(adcck,adcs)      (MCKCN1 =(MCKCN1&(~(MCKCN1_ADCCK_MSK | MCKCN1_ADCS_MSK)))|(adcck | adcs))
#define ADC_CLK_Disable()               (MCKCN1 &= ((~MCKCN1_ADCCK_MSK)&(~MCKCN1_ADCS_MSK)))
#define ADC_INT_Enable()                (INTE1 |= INTE1_ADCIE_ENABLE)
#define ADC_INT_Disable()               (INTE1 &= (~INTE1_ADCIE_MSK))
#define ADC_INT_IsFlag()                (INTF1 & INTF1_ADCIF_SET)
#define ADC_INT_ClearFlag()             (INTF1 &= (~INTF1_ADCIF_MSK))
#define ADC_INSEnable()                 (AINET1 |= AINET1_INIS_ENABLE)
#define ADC_INSDisable()                (AINET1 &= (~AINET1_INIS_MSK))
#define ADC_Enable()                    (ADCCN1 |= ADCCN1_ENADC_ENABLE)
#define ADC_Disable()                   (ADCCN1 &= (~ADCCN1_ENADC_MSK))
#define ADC_VRbufEnable()               (ADCCN2 |= ADCCN2_VRBUF_ENABLE)
#define ADC_VRbufDisable()              (ADCCN2 &= (~ADCCN2_VRBUF_MSK))
#define ADC_INbufEnable()               ADCCN2 |= ADCCN2_INBUF_ENABLE
#define ADC_INbufDisable()              ADCCN2 &= (~ADCCN2_INBUF_MSK)

#define ADC_AINConfig(inh,inl)          (AINET1 = ((AINET1 & (~(AINET1_INL_MSK | AINET1_INH_MSK))) | (inh | inl)))
#define ADC_VRINConfig(vrh,vrl)          AINET2 = ((AINET2 & (~(AINET2_VRL_MSK | AINET2_VRH_MSK))) | (vrh | vrl))
#define ADC_VRGainSelect(VRGSel)        (ADCCN2 = (ADCCN2 & (~ADCCN2_VREGN_MSK)) | VRGSel)
#define ADC_GainConfig(adgn,pgagn)      (ADCCN1 = ((ADCCN1 & (~(ADCCN1_ADGN_MSK | ADCCN1_PGAGN_MSK)))|(adgn | pgagn)) )
#define ADC_OSRConfig(osr)              (ADCCN3 = (ADCCN3 & (~ADCCN3_OSR_MSK)) | osr)
#define ADC_DCSetConfig(dcset)          (ADCCN2 = ((ADCCN2 & (~ADCCN2_DCSET_MSK)) | dcset))
#define ADC_INXConfig(inxmode)          (AINET2 = ((AINET2 & (~AINET2_INX_MSK)) | inxmode))

/*-------------------------------------------------------------------------------------------------|
|  Function call:                                                                                  |
|    For general and functional register access.                                                   |
|-------------------------------------------------------------------------------------------------*/
void ADC_Open(unsigned char ck,         //Selector of SD18 peripheral operating clock source
              unsigned char cks,        //Prescaler of SD18 peripheral operating frequency
              unsigned char inh,        //SI+ input signal selector
              unsigned char inl,        //SI- input signal selector
              unsigned char vrh,        //VR+ voltage signal selector
              unsigned char vrl,        //VR- voltage signal selector
              unsigned char adgn,       //AD amplification adjuster
              unsigned char pgagn,      //PGA amplification adjuster
              unsigned char vrgn,       //VR amplification adjuster
              unsigned char dcset,      //SI+/- bias adjuster
              unsigned char osr);       //SD18 over-sampling rate divider

long ADC_GetData(void);
