/**************************************************************************************************|
|* Copyright 2018 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|* - Generic Peripheral Library: A general and functional Interface for the specific Peripheral   *|
|* - Low Level Peripheral Access: Register-Bits Level access Macro, user must take care           *|
|*   of calling procedure and hardware constraints                                                *|
|* - Support Target: HY11P Series                                                                 *|
|**************************************************************************************************/

/**************************************************************************************************|
|*                               Peripheral Register Bits field                                   *|
|**************************************************************************************************/
// BIECTRLA //
#define BIECTRLA_VPPHIGH                 3
#define BIECTRLA_VPPHIGH_MSK            (1 << BIECTRLA_VPPHIGH)
#define BIECTRLA_VPPHIGH_NOCONNECT      (0 << BIECTRLA_VPPHIGH)
#define BIECTRLA_VPPHIGH_CONNECT        (1 << BIECTRLA_VPPHIGH)

#define BIECTRLA_BIEWR                   1
#define BIECTRLA_BIEWR_MSK              (1 << BIECTRLA_BIEWR)
#define BIECTRLA_BIEWR_NOTWRITABLE      (0 << BIECTRLA_BIEWR)
#define BIECTRLA_BIEWR_WRITABLE         (1 << BIECTRLA_BIEWR)

#define BIECTRLA_BIERD                   0
#define BIECTRLA_BIERD_MSK              (1 << BIECTRLA_BIERD)
#define BIECTRLA_BIERD_NOTREADABLE      (0 << BIECTRLA_BIERD)
#define BIECTRLA_BIERD_READABLE         (1 << BIECTRLA_BIERD)

// BIEPTRHA //
#define BIEPTRHA_BIESEL                  7
#define BIEPTRHA_BIESEL_MSK             (1 << BIEPTRHA_BIESEL)
#define BIEPTRHA_BIESEL_OTP             (0 << BIEPTRHA_BIESEL)
#define BIEPTRHA_BIESEL_BIE             (1 << BIEPTRHA_BIESEL)

#define BIEPTRHA_ADDRH                   0
#define BIEPTRHA_ADDRH_MSK              (7 << BIEPTRHA_ADDRH)

// BIEPTRLA //
#define BIEPTRLA_ADDRL                   0
#define BIEPTRLA_ADDRL_MSK              (255 << BIEPTRLA_ADDRL)   

// BIEDHA //
#define BIEDHA_DATAH                     0
#define BIEDHA_DATAH_MSK                (255 << BIEDHA_DATAH)
// BIEDLA //
#define BIEDLA_DATAL                     0
#define BIEDLA_DATAL_MSK                (255 << BIEDLA_DATAL)

//BIEPMP
#define PWRCN_ENBIEPMP                   2
#define PWRCN_ENBIEPMP_MSK              (1 << PWRCN_ENBIEPMP)
#define PWRCN_ENBIEPMP_OFF                      (0 << PWRCN_ENBIEPMP)
#define PWRCN_ENBIEPMP_ON                   (1 << PWRCN_ENBIEPMP)

/**************************************************************************************************|
|*                                      Function Level                                            *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function-like Macro:                                                                            |
|    Register Bits field Configuration without function call overhead,                             |
|    user should take care of detail of h/w behavior and constrains.                               |
|-------------------------------------------------------------------------------------------------*/
#define LCD_DisplayOn()                 (LCDCN2 &= (~LCDCN2_LCDBL_MSK))
#define LCD_DisplayOff()                (LCDCN2 |= LCDCN2_LCDBL_LCDOFF)

#define BIE_WriteConfig(WRSel)          (BIECTRLA = ((BIECTRLA & (~BIECTRLA_BIEWR_MSK)) | WRSel))
#define BIE_ReadConfig(RDSel)           (BIECTRLA = ((BIECTRLA & (~BIECTRLA_BIERD_MSK)) | RDSel))
#define BIE_Mode(ModeSel)               (BIECTRLA = ((BIECTRLA & (~BIEPTRHA_BIESEL_MSK)) | ModeSel))

#define BIE_AddrH(ADDRSel)              (BIEPTRHA = ((BIEPTRHA & (~BIEPTRHA_ADDRH_MSK)) | ADDRSel))
#define BIE_AddrL(ADDRSel)              (BIEPTRLA = ((BIEPTRLA & (~BIEPTRLA_ADDRL_MSK)) | ADDRSel))
#define BIE_DataH(DATASel)              (BIEDHA = ((BIEDHA & (~BIEDHA_DATAH_MSK)) | DATASel))
#define BIE_DataL(DATASel)              (BIEDLA = ((BIEDLA & (~BIEDLA_DATAL_MSK)) | DATASel))

#define BIE_EnBiePMP(PMPSel)           (PWRCN = ((PWRCN & (~PWRCN_ENBIEPMP_MSK)) | PMPSel))
#define BIECTRLA_VPPHIGH_GetStatus()    (BIECTRLA & BIECTRLA_VPPHIGH_CONNECT)

unsigned char WR5WORDBIEDATA(
                            unsigned char   BIE_AddrLset,
                            unsigned char   BIE_DataHset,
                            unsigned char   BIE_DataLset,
                            unsigned char (*dly)(void));

unsigned char HY11P54BLVBIEWORD(
                            unsigned char   BIE_AddrLset,
                            unsigned char   BIE_DataHset,
                            unsigned char   BIE_DataLset,
                            unsigned char (*dly)(void));
/*-------------------------------------------------------------------------------------------------|
|  Function call:                                                                                  |
|    For general and functional register access.                                                   |
|-------------------------------------------------------------------------------------------------*/
