/**************************************************************************************************|
|* Copyright 2016 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|*                                                                                                *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Includes                                                                                      *|
|**************************************************************************************************/
#include <hy11s14sfr.h>    // Peripheral Register Memory Mapping
#include "CCP.h"

/**************************************************************************************************|
|*  Static Function                                                                               *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Generic Peripheral Library                                                                    *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function: CCP_Open                                                                              |
|                                                                                                  |
|  Parameters:                                                                                     |
|         ccp0m     - [in] CCPCN_CCP0M_CLOSE , CCPCN_CCP0M_REVCCP                                  |
|                          CCPCN_CCP0M_FALL1 , CCPCN_CCP0M_RISE1                                   |
|                          CCPCN_CCP0M_RISE4 , CCPCN_CCP0M_RISE16                                  |
|                          CCPCN_CCP0M_HICCP , CCPCN_CCP0M_LOWCCP                                  |
|                          CCPCN_CCP0M_NOCCP , CCPCN_CCP0M_CLRTMB                                  |
|         ccp1m     - [in] CCPCN_CCP1M_CLOSE , CCPCN_CCP1M_REVCCP                                  |
|                          CCPCN_CCP1M_FALL1 , CCPCN_CCP1M_RISE1                                   |
|                          CCPCN_CCP1M_RISE4 , CCPCN_CCP1M_RISE16                                  |
|                          CCPCN_CCP1M_HICCP , CCPCN_CCP1M_LOWCCP                                  |
|                          CCPCN_CCP1M_NOCCP , CCPCN_CCP1M_CLRTMB                                  |
|                                                                                                  |
|  Returns:                                                                                        |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                    |
|         This function is used to open the Capture or Compare(CCP)                                |
|-------------------------------------------------------------------------------------------------*/
void CCP_Open(unsigned char ccp0m, //CCP0 function select control
              unsigned char ccp1m) //CCP1 function select control
{
    CCP_CCP0Mode(ccp0m);
    CCP_CCP1Mode(ccp1m);
}

/*-------------------------------------------------------------------------------------------------|
|  Function: CCP_SetDatax                                                                          |
|                                                                                                  |
|  Parameters:                                                                                     |
|         CCPdata     - [in] Enter the 16-bit data for CCPxR                                       |
|                                                                                                  |
|  Returns:                                                                                        |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                    |
|         This function is used to Set the Data for CCPx (x = 0 or 1)                              |
|-------------------------------------------------------------------------------------------------*/
void CCP_SetData0(unsigned int CCPdata)
{
    CCP0RL=((char *)(&CCPdata))[0];
    CCP0RH=((char *)(&CCPdata))[1];
}

void CCP_SetData1(unsigned int CCPdata)
{
    CCP1RL=((char *)(&CCPdata))[0];
    CCP1RH=((char *)(&CCPdata))[1];
}

/*-------------------------------------------------------------------------------------------------|
|  Function: CCP_GetDatax                                                                          |
|                                                                                                  |
|  Parameters:                                                                                     |
|         None                                                                                     |
|                                                                                                  |
|  Returns:                                                                                        |
|         CCPdata     - [in] Read the 16-bit data for CCPxR                                        |
|                                                                                                  |
|  Description:                                                                                    |
|         This function is used to Read the Data for CCPx (x = 0 or 1)                             |
|-------------------------------------------------------------------------------------------------*/
int CCP_GetData0(void)
{
    int CCPdata;
    ((char *)(&CCPdata))[0]=CCP0RL;
    ((char *)(&CCPdata))[1]=CCP0RH;
    return CCPdata;
}

int CCP_GetData1(void)
{
    int CCPdata;
    ((char *)(&CCPdata))[0]=CCP1RL;
    ((char *)(&CCPdata))[1]=CCP1RH;
    return CCPdata;
}

/**************************************************************************************************|
|*  Static Functions                                                                              *|
|**************************************************************************************************/
