/**************************************************************************************************|
|* Copyright 2016 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|* - Generic Peripheral Library: A general and functional Interface for the specific Peripheral   *|
|* - Low Level Peripheral Access: Register-Bits Level access Macro, user must take care           *|
|*   of calling procedure and hardware constraints                                                *|
|* - Support Target: HY11P Series                                                                 *|
|**************************************************************************************************/
#include <INT.h>           // Interrupt Config for CCP

/**************************************************************************************************|
|*                               Peripheral Register Bits field                                   *|
|**************************************************************************************************/
// CCPCN //
#define CCPCN_CCP1M                      4
#define CCPCN_CCP1M_MSK                 (15 << CCPCN_CCP1M)
#define CCPCN_CCP1M_CLRTMB              (11 << CCPCN_CCP1M)  //Compare, CCP1IF=1, Timer-B is zeroed
#define CCPCN_CCP1M_NOCCP               (10 << CCPCN_CCP1M)  //Compare, CCP1IF=1, no signal to CCP1
#define CCPCN_CCP1M_LOWCCP              (9 << CCPCN_CCP1M)   //Compare, CCP1IF=1, logic low to CCP1
#define CCPCN_CCP1M_HICCP               (8 << CCPCN_CCP1M)   //Compare, CCP1IF=1, logic high to CCP1
#define CCPCN_CCP1M_RISE16              (7 << CCPCN_CCP1M)   //Capture, CCP1IF=1, every 16 rising edge
#define CCPCN_CCP1M_RISE4               (6 << CCPCN_CCP1M)   //Capture, CCP1IF=1, every 4 rising edge
#define CCPCN_CCP1M_RISE1               (5 << CCPCN_CCP1M)   //Capture, CCP1IF=1, every 1 rising edge
#define CCPCN_CCP1M_FALL1               (4 << CCPCN_CCP1M)   //Capture, CCP1IF=1, every 1 falling edge
#define CCPCN_CCP1M_REVCCP              (2 << CCPCN_CCP1M)   //Compare, CCP1IF=1, reversed CCP1
#define CCPCN_CCP1M_CLOSE               (0 << CCPCN_CCP1M)   //Close Capture/Compare Mode function

#define CCPCN_CCP0M                      0
#define CCPCN_CCP0M_MSK                 (15 << CCPCN_CCP0M)
#define CCPCN_CCP0M_CLRTMB              (11 << CCPCN_CCP0M)  //Compare, CCP0IF=1, Timer-B is zeroed
#define CCPCN_CCP0M_NOCCP               (10 << CCPCN_CCP0M)  //Compare, CCP0IF=1, no signal to CCP0
#define CCPCN_CCP0M_LOWCCP              (9 << CCPCN_CCP0M)   //Compare, CCP0IF=1, logic low to CCP0
#define CCPCN_CCP0M_HICCP               (8 << CCPCN_CCP0M)   //Compare, CCP0IF=1, logic high to CCP0
#define CCPCN_CCP0M_RISE16              (7 << CCPCN_CCP0M)   //Capture, CCP0IF=1, every 16 rising edge
#define CCPCN_CCP0M_RISE4               (6 << CCPCN_CCP0M)   //Capture, CCP0IF=1, every 4 rising edge
#define CCPCN_CCP0M_RISE1               (5 << CCPCN_CCP0M)   //Capture, CCP0IF=1, every 1 rising edge
#define CCPCN_CCP0M_FALL1               (4 << CCPCN_CCP0M)   //Capture, CCP0IF=1, every 1 falling edge
#define CCPCN_CCP0M_REVCCP              (2 << CCPCN_CCP0M)   //Compare, CCP0IF=1, reversed CCP0
#define CCPCN_CCP0M_CLOSE               (0 << CCPCN_CCP0M)   //Close Capture/Compare Mode function

/**************************************************************************************************|
|*                                      Function Level                                            *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function-like Macro:                                                                            |
|    Register Bits field Configuration without function call overhead,                             |
|    user should take care of detail of h/w behavior and constrains.                               |
|-------------------------------------------------------------------------------------------------*/

#define CCP_INT0_Enable()               (INTE2 |= INTE2_CCP0IE_ENABLE)
#define CCP_INT0_Disable()              (INTE2 &= (~INTE2_CCP0IE_MSK))
#define CCP_INT0_IsFlag()               (INTF2 & INTF2_CCP0IF_SET)
#define CCP_INT0_ClearFlag()            (INTF2 &= (~INTF2_CCP0IF_MSK))
#define CCP_INT1_Enable()               (INTE2 |= INTE2_CCP1IE_ENABLE)
#define CCP_INT1_Disable()              (INTE2 &= (~INTE2_CCP1IE_MSK))
#define CCP_INT1_IsFlag()               (INTF2 & INTF2_CCP1IF_SET)
#define CCP_INT1_ClearFlag()            (INTF2 &= (~INTF2_CCP1IF_MSK))

#define CCP_CCP1Mode(CCP1Sel)           (CCPCN = ((CCPCN & (~CCPCN_CCP1M_MSK)) | CCP1Sel))
#define CCP_CCP0Mode(CCP0Sel)           (CCPCN = ((CCPCN & (~CCPCN_CCP0M_MSK)) | CCP0Sel))

/*-------------------------------------------------------------------------------------------------|
|  Function call:                                                                                  |
|    For general and functional register access.                                                   |
|-------------------------------------------------------------------------------------------------*/
void CCP_Open(unsigned char ccp0m,      //CCP0 function select control
              unsigned char ccp1m);     //CCP1 function select control
int CCP_GetData0(void);
int CCP_GetData1(void);
void CCP_SetData0(unsigned int CCP0data);
void CCP_SetData1(unsigned int CCP1data);
