/**************************************************************************************************|
|* Copyright 2016 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|*                                                                                                *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Includes                                                                                      *|
|**************************************************************************************************/
#include <hy11s14sfr.h>    // Peripheral Register Memory Mapping
#include <CLK.h>

/**************************************************************************************************|
|*  Static Function                                                                               *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Generic Peripheral Library                                                                    *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function: CLK_GPIO_OpenXTInput                                                                      |
|                                                                                                  |
|  Parameters:                                                                                     |
|         None                                                                                     |
|                                                                                                  |
|  Returns:                                                                                        |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                    |
|         This function is used to open the XT mode for Pin setting                                |
|-------------------------------------------------------------------------------------------------*/
void CLK_GPIO_OpenXTInput(void)
{
    TRISC2 &= (~(TRISC2_TC20_MSK | TRISC2_TC21_MSK));  // config PT2.0/PT2.1 as Input Mode
    PT2PU &= (~(PT2PU_PU20_MSK | PT2PU_PU21_MSK));     // Disable Input pull up in case of Input Mode
}

/*-------------------------------------------------------------------------------------------------|
|  Function: CLK_CPUCKOpen                                                                         |
|                                                                                                  |
|  Parameters:                                                                                     |
|         CPUCKSel  - [in] MCKCN2_CPUCK_HSSCK  / MCKCN2_CPUCK_HSDCK                                |
|                          MCKCN2_CPUCK_LSCK   / MCKCN2_CPUCK_HSCK                                 |
|         ExtCKEn   - [in] MCKCN1_ENXT_DISABLE / MCKCN1_ENXT_ENABLE                                |
|         HSSCKDiv  - [in] MCKCN2_HSS_HSCKDIV1 / MCKCN2_HSS_HSCKDIV2                               |
|                          MCKCN2_HSS_HSCKDIV4 / MCKCN2_HSS_HSCKDIV8                               |
|                                                                                                  |
|  Returns:                                                                                        |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                    |
|         This function is used to open the CPU clock setting                                      |
|-------------------------------------------------------------------------------------------------*/
/*void CLK_CPUCKOpen(unsigned char CPUCKSel,unsigned char ExtCKEn,unsigned char HSSCKDiv)
{
    // CLK Register Default setting
    MCKCN1 |= MCKCN1_ENHAO_ENABLE;    // ENABLE HAO
    MCKCN2 = 0;                       // Config HSCK to HAO, LSCK to LPO, and CPUCK to HSSCK(HSCK/1)
    MCKCN1 &= MCKCN1_ENHAO_MSK;       // Disable Ext oscillator
    MCKCN3 =0;                        // Default setting

    // CLK Register config.
    if(ExtCKEn)  // XTCK source
    {
       unsigned int i;
        MCKCN1 |= ExtCKEn;                                       // Enable Ext. Oscillator
        if(CPUCKSel != MCKCN2_CPUCK_LSCK)                        // CPUCK= HSCK, HSSCK or HSDCK
        {
            MCKCN1 |= MCKCN1_XTSP_XTS;                           // Set as XTSP=XTS
            i=0x200;                                        // delay 30ms until Oscillator is stable
            while(i--);
            MCKCN2 |= (MCKCN2_HSCK_CY | CPUCKSel | HSSCKDiv);    // HSCK = Ext., CPUCK Cofig as required
        }
        else
        {
            i=20000;                                       // delay 1s until Oscillator is stable
            while(i--);
            MCKCN2 |= (MCKCN2_LSCK_CY | CPUCKSel);                // LSCK = Ext., CPUCK Cofig as required
        }
    }
    else // HAO,LPO
    {
        if(CPUCKSel != MCKCN2_CPUCK_LSCK);                     // CPUCK= HSCK, HSSCK or HSDCK
        {
            MCKCN2 |= HSSCKDiv;
        }
        MCKCN2 |=  CPUCKSel;
    }

}//*/


/*-------------------------------------------------------------------------------------------------|
|  Function: CLK_CPUCKOpen                                                                         |
|                                                                                                  |
|  Parameters:                                                                                     |
|         CPUCKSel  - [in] MCKCN2_CPUCK_HSSCK  / MCKCN2_CPUCK_HSDCK                                |
|                          MCKCN2_CPUCK_LSCK   / MCKCN2_CPUCK_HSCK                                 |
|         ExtCKEn   - [in] MCKCN1_ENXT_DISABLE / MCKCN1_ENXT_ENABLE                                |
|         HSSCKDiv  - [in] MCKCN2_HSS_HSCKDIV1 / MCKCN2_HSS_HSCKDIV2                               |
|                          MCKCN2_HSS_HSCKDIV4 / MCKCN2_HSS_HSCKDIV8                               |
|         VXTSP -    [in] MCKCN1_XTSP                                         |
|         oscSOURCE - [in] MCKCN2_LSCK/MCKCN2_HSCK
|                                                                                                  |
|  Returns:                                                                                        |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                    |
|         This function is used to open the CPU clock setting          
|  Modify date: 2017/07/19 marck                            |
|-------------------------------------------------------------------------------------------------*/
void CLK_CPUCKOpen(
unsigned char CPUCKSel,
unsigned char ExtCKEn,
unsigned char HSSCKDiv,
unsigned char VXTSP,
unsigned char oscSOURCE)
{
    unsigned char var;

  //ENABLE the external OSC_CRY and choose the high speed or low;
  if(ExtCKEn==0)  // XTCK source
  {
  	// if disable the external CRY, must enable the HAO first,and then change the OSC_source,and then disable the external CRY after above;
   	var=MCKCN1&MCKCN1_XTSP_MSK; 
  	if(var!=0)           // if the external is XTSh
  	{
  	    MCKCN1 |= MCKCN1_ENHAO_ENABLE;    // ENABLE HAO
    } 
   if(CPUCKSel != MCKCN2_CPUCK_LSCK)                        // CPUCK= HSCK, HSSCK or HSDCK
     {
            var=MCKCN2&(~(MCKCN2_CPUCK_MSK|MCKCN2_HSS_MSK|MCKCN2_HSCK_MSK));
            //var |=oscSOURCE;            
            //var|= (CPUCKSel | HSSCKDiv);// HSCK                  
      }
   else
      {
            var=MCKCN2&(~(MCKCN2_CPUCK_MSK|MCKCN2_HSS_MSK|MCKCN2_LSCK_MSK));
       }  
     var |=oscSOURCE;             
     var|=(CPUCKSel | HSSCKDiv);// LSCK       
     MCKCN2 = var;                         //SETTING THE OSC COME FROM THE INTERNAL OR EXTERNAL
  }
  //setting external 
  var =(MCKCN1_ENXT_MSK|MCKCN1_XTSP_MSK);  //modify on 20170914
  var=~var;                                //modify on 20170914
  var =(MCKCN1&var)|VXTSP;
  MCKCN1 = var;
  MCKCN1|=ExtCKEn; 
 if(ExtCKEn)  // XTCK source
 { // setting  external OSC_CRY steable time;
  unsigned int i;
  i=0x3f;
  if((MCKCN1&0X02)!=0X02)   //if the cpu_ck=lsck 
    i=20000;
  while(i--);                              // wait for external OSC_CRY steable
 }

 if(CPUCKSel != MCKCN2_CPUCK_LSCK)                        // CPUCK= HSCK, HSSCK or HSDCK
  {
            var=MCKCN2&(~(MCKCN2_CPUCK_MSK|MCKCN2_HSS_MSK|MCKCN2_HSCK_MSK));
            var |=oscSOURCE;            
            var|= (CPUCKSel | HSSCKDiv);// HSCK
            MCKCN2 = var;                         //SETTING THE OSC COME FROM THE INTERNAL OR EXTERNAL           
            if(oscSOURCE)   // if the OSC_SOURCE IS EXTERNAL ,AND THEN DISABLE THE HAO
            {
            MCKCN1 &= (~MCKCN1_ENHAO_ENABLE );       // Disable HAO
            }
                   
  }
  else
  {
            var=MCKCN2&(~(MCKCN2_CPUCK_MSK|MCKCN2_LSCK_MSK));
            var |=oscSOURCE;             
            var|= CPUCKSel ;// LSCK 
            MCKCN2 = var;                         //SETTING THE OSC COME FROM THE INTERNAL OR EXTERNAL           
            MCKCN1 &= (~MCKCN1_ENHAO_ENABLE );       // Disable HAO
  }  

}
/**************************************************************************************************|
|*  Static Functions                                                                              *|
|**************************************************************************************************/
