/**************************************************************************************************|
|* Copyright 2016 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|*                                                                                                *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Includes                                                                                      *|
|**************************************************************************************************/
#include <hy11s14sfr.h>    // Peripheral Register Memory Mapping
#include <ECPA.h>
#include <GPIO.h>

/**************************************************************************************************|
|*  Static Function                                                                               *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Generic Peripheral Library                                                                    *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function: ECPA_Open                                                                             |
|                                                                                                  |
|  Parameters:                                                                                     |
|         cpil      - [in] CPACN1_CPIL_HIZ      / CPACN1_CPIL_CAPI1                                |
|                          CPACN1_CPIL_CAPI2    / CPACN1_CPIL_CAPI3                                |
|                          CPACN1_CPIL_CAPI4    / CPACN1_CPIL_CAPI5                                |
|                          CPACN1_CPIL_CAPI6    / CPACN1_CPIL_CAPI7                                |
|         cpih      - [in] CPACN1_CPIH_HIZ      / CPACN1_CPIH_CAPI0                                |
|                          CPACN1_CPIH_CAPI1    / CPACN1_CPIH_CAPI2                                |
|         cpvcs     - [in] CPACN2_CPVCS_HIZ     / CPACN2_CPVCS_REFTEMP                             |
|                          CPACN2_CPVCS_VDDDIV4 / CPACN2_CPVCS_VDDDIV2                             |
|         cpvrx     - [in] CPACN3_CPVRX_HIZ     / CPACN3_CPVRX_0V0625                              |
|                          CPACN3_CPVRX_0V125   / CPACN3_CPVRX_0V1875                              |
|                          CPACN3_CPVRX_0V250   / CPACN3_CPVRX_0V3125                              |
|                          CPACN3_CPVRX_0V375   / CPACN3_CPVRX_0V4375                              |
|                          CPACN3_CPVRX_0V5625  / CPACN3_CPVRX_0V625                               |
|                          CPACN3_CPVRX_0V6875  / CPACN3_CPVRX_0V750                               |
|                          CPACN3_CPVRX_0V8125  / CPACN3_CPVRX_0V875                               |
|                          CPACN3_CPVRX_0V9375  / CPACN3_CPVRX_1V000                               |
|         output    - [in] "0" => CPOIF & No output pin                                            |
|                          "1" => CPOIF & PT2.6                                                    |
|                          "2" => CPOIF & PT2.7                                                    |
|                          "3" => CPOIF & PT2.6 & PT2.7                                            |
|                                                                                                  |
|  Returns:                                                                                        |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                    |
|         This function is used to open the Enhanced Comparator(ECPA)                              |
|-------------------------------------------------------------------------------------------------*/
void ECPA_Open(unsigned char cpil,      //Comparator input channel selector
               unsigned char cpih,      //Comparator input channel selector
               unsigned char cpvcs,     //voltage reference generator I signal output select control bit
               unsigned char cpvrx,     //Voltage reference generator II outputs voltage control bit (ACM=1V configuration)
               unsigned char output)    //Comparator output channel selector
{
    ECPA_Enable();
    ECPA_InChanL(cpil);
    ECPA_InChanH(cpih);
    ECPA_RefVolChan1(cpvcs);
    ECPA_RefVolChan2(cpvrx);

    if(output == 1)
    {
        GPIO_PT2OutputMode(TRISC2_TC26_OUTPUT);
        GPIO_PM26Sel(PT2M2_PM26_CPAO);
    }

    if(output == 2)
    {
        GPIO_PT2OutputMode(TRISC2_TC27_OUTPUT);
        GPIO_PM27Sel(PT2M2_PM27_CPAO);
    }

    if(output == 3)
    {
        GPIO_PT2OutputMode(TRISC2_TC27_OUTPUT);
        GPIO_PM27Sel(PT2M2_PM27_CPAO);
        GPIO_PT2OutputMode(TRISC2_TC26_OUTPUT);
        GPIO_PM26Sel(PT2M2_PM26_CPAO);
    }
}

/**************************************************************************************************|
|*  Static Functions                                                                              *|
|**************************************************************************************************/
