/**************************************************************************************************|
|* Copyright 2016 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|* - Generic Peripheral Library: A general and functional Interface for the specific Peripheral   *|
|* - Low Level Peripheral Access: Register-Bits Level access Macro, user must take care           *|
|*   of calling procedure and hardware constraints                                                *|
|* - Support Target: HY11P Series                                                                 *|
|**************************************************************************************************/
#include <INT.h>           // Interrupt Config for ECPA

/**************************************************************************************************|
|*                               Peripheral Register Bits field                                   *|
|**************************************************************************************************/
// CPACN1 //
#define CPACN1_ENCPA                     7
#define CPACN1_ENCPA_MSK                (1 << CPACN1_ENCPA)
#define CPACN1_ENCPA_ENABLE             (1 << CPACN1_ENCPA)
#define CPACN1_ENCPA_DISABLE            (0 << CPACN1_ENCPA)

#define CPACN1_CPIST                     6
#define CPACN1_CPIST_MSK                (1 << CPACN1_CPIST)
#define CPACN1_CPIST_SHORT              (1 << CPACN1_CPIST)
#define CPACN1_CPIST_OPEN               (0 << CPACN1_CPIST)

#define CPACN1_CPIX                      5
#define CPACN1_CPIX_MSK                 (1 << CPACN1_CPIX)
#define CPACN1_CPIX_SWITCH              (1 << CPACN1_CPIX)
#define CPACN1_CPIX_NOTSWITCH           (0 << CPACN1_CPIX)

#define CPACN1_CPIH                      3
#define CPACN1_CPIH_MSK                 (3 << CPACN1_CPIH)
#define CPACN1_CPIH_CAPI2               (3 << CPACN1_CPIH)
#define CPACN1_CPIH_CAPI1               (2 << CPACN1_CPIH)
#define CPACN1_CPIH_CAPI0               (1 << CPACN1_CPIH)
#define CPACN1_CPIH_HIZ                 (0 << CPACN1_CPIH)   //High impedance

#define CPACN1_CPIL                      0
#define CPACN1_CPIL_MSK                 (7 << CPACN1_CPIL)
#define CPACN1_CPIL_CAPI7               (7 << CPACN1_CPIL)
#define CPACN1_CPIL_CAPI6               (6 << CPACN1_CPIL)
#define CPACN1_CPIL_CAPI5               (5 << CPACN1_CPIL)
#define CPACN1_CPIL_CAPI4               (4 << CPACN1_CPIL)
#define CPACN1_CPIL_CAPI3               (3 << CPACN1_CPIL)
#define CPACN1_CPIL_CAPI2               (2 << CPACN1_CPIL)
#define CPACN1_CPIL_CAPI1               (1 << CPACN1_CPIL)
#define CPACN1_CPIL_HIZ                 (0 << CPACN1_CPIL)   //Low impedance

// CPACN2 //
#define CPACN2_CPOX                      6
#define CPACN2_CPOX_MSK                 (1 << CPACN2_CPOX)
#define CPACN2_CPOX_REVERSE             (1 << CPACN2_CPOX)
#define CPACN2_CPOX_NOTREVERSE          (0 << CPACN2_CPOX)

#define CPACN2_CPOFR                     5
#define CPACN2_CPOFR_MSK                (1 << CPACN2_CPOFR)
#define CPACN2_CPOFR_FILTER             (1 << CPACN2_CPOFR)
#define CPACN2_CPOFR_NOTFILTER          (0 << CPACN2_CPOFR)

#define CPACN2_CS1                       4
#define CPACN2_CS1_MSK                  (1 << CPACN2_CS1)
#define CPACN2_CS1_P                    (1 << CPACN2_CS1)   //CPIX=0,Comparator - edge ; CPIX=1,Comparator + ed
#define CPACN2_CS1_N                    (0 << CPACN2_CS1)   //CPIX=0,Comparator + edge ; CPIX=1,Comparator - ed

#define CPACN2_CPAT                      3
#define CPACN2_CPAT_MSK                 (1 << CPACN2_CPAT)
#define CPACN2_CPAT_AUTO                (1 << CPACN2_CPAT)
#define CPACN2_CPAT_NORMAL              (0 << CPACN2_CPAT)

#define CPACN2_CPVCS                     1
#define CPACN2_CPVCS_MSK                (3 << CPACN2_CPVCS)
#define CPACN2_CPVCS_VDDDIV2            (3 << CPACN2_CPVCS)
#define CPACN2_CPVCS_VDDDIV4            (2 << CPACN2_CPVCS)
#define CPACN2_CPVCS_REFTEMP            (1 << CPACN2_CPVCS)
#define CPACN2_CPVCS_HIZ                (0 << CPACN2_CPVCS)   //High impedance

// CPACN3 //
#define CPACN3_CS2                       4
#define CPACN3_CS2_MSK                  (1 << CPACN3_CS2)
#define CPACN3_CS2_P                    (1 << CPACN3_CS2)   //CPIX=0,Comparator - edge ; CPIX=1,Comparator + ed
#define CPACN3_CS2_N                    (0 << CPACN3_CS2)   //CPIX=0,Comparator + edge ; CPIX=1,Comparator - ed

#define CPACN3_CPVRX                     0  //error definechange '1' for '0'modify:20170718
#define CPACN3_CPVRX_MSK                (15 << CPACN3_CPVRX)
#define CPACN3_CPVRX_1V000              (15 << CPACN3_CPVRX)
#define CPACN3_CPVRX_0V9375             (14 << CPACN3_CPVRX)
#define CPACN3_CPVRX_0V875              (13 << CPACN3_CPVRX)
#define CPACN3_CPVRX_0V8125             (12 << CPACN3_CPVRX)
#define CPACN3_CPVRX_0V750              (11 << CPACN3_CPVRX)
#define CPACN3_CPVRX_0V6875             (10 << CPACN3_CPVRX)
#define CPACN3_CPVRX_0V625              (9 << CPACN3_CPVRX)
#define CPACN3_CPVRX_0V5625             (8 << CPACN3_CPVRX)
#define CPACN3_CPVRX_0V4375             (7 << CPACN3_CPVRX)
#define CPACN3_CPVRX_0V375              (6 << CPACN3_CPVRX)
#define CPACN3_CPVRX_0V3125             (5 << CPACN3_CPVRX)
#define CPACN3_CPVRX_0V250              (4 << CPACN3_CPVRX)
#define CPACN3_CPVRX_0V1875             (3 << CPACN3_CPVRX)
#define CPACN3_CPVRX_0V125              (2 << CPACN3_CPVRX)
#define CPACN3_CPVRX_0V0625             (1 << CPACN3_CPVRX)
#define CPACN3_CPVRX_HIZ                (0 << CPACN3_CPVRX)   //High impedance

/**************************************************************************************************|
|*                                      Function Level                                            *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function-like Macro:                                                                            |
|    Register Bits field Configuration without function call overhead,                             |
|    user should take care of detail of h/w behavior and constrains.                               |
|-------------------------------------------------------------------------------------------------*/
#define ECPA_INT_Enable()               (INTE2 |= INTE2_CPOIE_ENABLE)
#define ECPA_INT_Disable()              (INTE2 &= (~INTE2_CPOIE_MSK))
#define ECPA_INT_IsFlag()               (INTF2 & INTF2_CPOIF_SET)
#define ECPA_INT_ClearFlag()            (INTF2 &= (~INTF2_CPOIF_MSK))
#define ECPA_Enable()                   (CPACN1 |= CPACN1_ENCPA_ENABLE)
#define ECPA_Disable()                  (CPACN1 &= (~CPACN1_ENCPA_MSK))

#define ECPA_InShort(ISTSel)            (CPACN1 = ((CPACN1 & (~CPACN1_CPIST_MSK)) | ISTSel))
#define ECPA_SignConverter(IXSel)       (CPACN1 = ((CPACN1 & (~CPACN1_CPIX_MSK)) | IXSel))
#define ECPA_InChanH(IHSel)             (CPACN1 = ((CPACN1 & (~CPACN1_CPIH_MSK)) | IHSel))
#define ECPA_InChanL(ILSel)             (CPACN1 = ((CPACN1 & (~CPACN1_CPIL_MSK)) | ILSel))
#define ECPA_OutReverse(OXSel)          (CPACN2 = ((CPACN2 & (~CPACN2_CPOX_MSK)) | OXSel))
#define ECPA_SignProcessor(OFRSel)      (CPACN2 = ((CPACN2 & (~CPACN2_CPOFR_MSK)) | OFRSel))
#define ECPA_OutState(ATSel)            (CPACN2 = ((CPACN2 & (~CPACN2_CPAT_MSK)) | ATSel))//ERRO DEFINE: input pattern change 'CS1Sel' for 'ATSel';modify:20170718
#define ECPA_Ref2CompIn1(CS1Sel)        (CPACN2 = ((CPACN2 & (~CPACN2_CS1_MSK)) | CS1Sel))
#define ECPA_RefVolChan1(VCSSel)        (CPACN2 = ((CPACN2 & (~CPACN2_CPVCS_MSK)) | VCSSel))
#define ECPA_Ref2CompIn2(CS2Sel)        (CPACN3 = ((CPACN3 & (~CPACN3_CS2_MSK)) | CS2Sel))
#define ECPA_RefVolChan2(VRXSel)        (CPACN3 = ((CPACN3 & (~CPACN3_CPVRX_MSK)) | VRXSel))


/*-------------------------------------------------------------------------------------------------|
|  Function call:                                                                                  |
|    For general and functional register access.                                                   |
|-------------------------------------------------------------------------------------------------*/
void ECPA_Open(unsigned char cpil,      //Comparator input channel selector
               unsigned char cpih,      //Comparator input channel selector
               unsigned char cpvcs,     //voltage reference generator I signal output select control bit
               unsigned char cpvrx,     //Voltage reference generator II outputs voltage control bit (ACM=1V configuration)
               unsigned char output);   //Comparator output channel selector
