/**************************************************************************************************|
|* Copyright 2016 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|*                                                                                                *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Includes                                                                                      *|
|**************************************************************************************************/
#include <hy11s14sfr.h>    // Peripheral Register Memory Mapping
#include <GPIO.h>
#include <CLK.h>

/**************************************************************************************************|
|*  Static Function                                                                               *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Generic Peripheral Library                                                                    *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function: GPIO_OpenPTxInput                                                                     |
|                                                                                                  |
|  Parameters:                                                                                     |
|         InputBits    - [in] Enter the 8-bit data for Pin setting                                 |
|         PullHighBits - [in] Enter the 8-bit data for Pin setting                                 |
|                                                                                                  |
|  Returns:                                                                                        |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                    |
|         This function is used to open the PTx input mode (1 <= x <= 5)                           |
|-------------------------------------------------------------------------------------------------*/
void GPIO_OpenPT1Input(unsigned char InputBits,unsigned char PullHighBits)
{
    //GPIO_PT1DigitalMode(InputBits);//modify 2018/8/27
    GPIO_PT1InputMode(InputBits);
    GPIO_PT1InputPullHight(PullHighBits);//(InputBits & PullHighBits); //modify 2018/8/27
}
void GPIO_OpenPT2Input(unsigned char InputBits,unsigned char PullHighBits)
{
    GPIO_PT2InputMode(InputBits);
    GPIO_PT2InputPullHight(PullHighBits);//(InputBits & PullHighBits);//modify 2018/8/27
}
void GPIO_OpenPT3Input(unsigned char InputBits,unsigned char PullHighBits)
{
    GPIO_PT3InputMode(InputBits);
    GPIO_PT3InputPullHight(PullHighBits);//(InputBits & PullHighBits);//modify 2018/8/27
}
void GPIO_OpenPT4Input(unsigned char InputBits,unsigned char PullHighBits)
{
    GPIO_PT4DigitalMode(InputBits);
    GPIO_PT4InputPullHight(PullHighBits);//(InputBits & PullHighBits);//modify 2018/8/27
}
void GPIO_OpenPT5Input(unsigned char InputBits,unsigned char PullHighBits)
{
    GPIO_PT5DigitalMode(InputBits);
    GPIO_PT5InputPullHight(PullHighBits);//(InputBits & PullHighBits);//modify 2018/8/27
}

/*-------------------------------------------------------------------------------------------------|
|  Function: GPIO_OpenPTxOuput                                                                     |
|                                                                                                  |
|  Parameters:                                                                                     |
|         OutputBits  - [in] Enter the 8-bit data for Pin setting                                  |
|         OutHighBits - [in] Enter the 8-bit data for Pin setting                                  |
|                                                                                                  |
|  Returns:                                                                                        |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                    |
|         This function is used to open the PTx ouput mode (1 <= x <= 5)                           |
|-------------------------------------------------------------------------------------------------*/
void GPIO_OpenPT1Ouput(unsigned char OutputBits,unsigned char OutHighBits)
{
    GPIO_PT1OutputMode(OutputBits);
    GPIO_PT1OutputHigh(OutHighBits);//(OutputBits & OutHighBits);//modify 20180827
}
void GPIO_OpenPT2Ouput(unsigned char OutputBits,unsigned char OutHighBits)
{
    GPIO_PT2OutputMode(OutputBits);
    GPIO_PT2OutputHigh(OutHighBits);//(OutputBits & OutHighBits);//modify 20180827
}
void GPIO_OpenPT3Ouput(unsigned char OutputBits,unsigned char OutHighBits)
{
    GPIO_PT3OutputMode(OutputBits);
    GPIO_PT3OutputHigh(OutHighBits);//(OutputBits & OutHighBits);//modify 20180827
}

/*-------------------------------------------------------------------------------------------------|
|  Function: BZ_Open                                                                               |
|                                                                                                  |
|  Parameters:                                                                                     |
|         cks       - [in] MCKCN3_BZS_PERCKDIV1  / MCKCN3_BZS_PERCKDIV3                            |
|                          MCKCN3_BZS_PERCKDIV4  / MCKCN3_BZS_PERCKDIV8                            |
|                          MCKCN3_BZS_PERCKDIV16 / MCKCN3_BZS_PERCKDIV32                           |
|                          MCKCN3_BZS_PERCKDIV64 / MCKCN3_BZS_PERCKDIV128                          |
|                                                                                                  |
|  Returns:                                                                                        |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                    |
|         This function is used to open the Buzzer mode                                            |
|-------------------------------------------------------------------------------------------------*/
void BZ_Open(unsigned char cks)
{
  CLK_BZCKSel(cks);
  GPIO_PT1OutputMode(TRISC1_TC17_OUTPUT);
}

/**************************************************************************************************|
|*  Static Functions                                                                              *|
|**************************************************************************************************/
