/**************************************************************************************************|
|* Copyright 2016 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|*                                                                                                *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Includes                                                                                      *|
|**************************************************************************************************/
#include <hy11s14sfr.h>    // Peripheral Register Memory Mapping
#include <LCD.h>
#include <CLK.h>

/**************************************************************************************************|
|*  Static Function                                                                               *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Generic Peripheral Library                                                                    *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function: LCD_Open                                                                              |
|                                                                                                  |
|  Parameters:                                                                                     |
|         lcdpr     - [in] LCDCN1_LCDPR_EXTERNAL   / LCDCN1_LCDPR_INTERNAL                         |
|         ckdiv     - [in] MCKCN3_LCDS_PERACKDIV1  / MCKCN3_LCDS_PERACKDIV2                        |
|                          MCKCN3_LCDS_PERACKDIV4  / MCKCN3_LCDS_PERACKDIV8                        |
|                          MCKCN3_LCDS_PERACKDIV16 / MCKCN3_LCDS_PERACKDIV32                       |
|                          MCKCN3_LCDS_PERACKDIV64 / MCKCN3_LCDS_PERACKDIV128                      |
|         vlcdx     - [in] LCDCN1_VLCDX_2V55            / LCDCN1_VLCDX_2V8                                  |
|                          LCDCN1_VLCDX_3V05           / LCDCN1_VLCDX_3V3                                |
|         lcdmx     - [in] LCDCN2_LCDMX_Static     / LCDCN2_LCDMX_duty2                             |
|                          LCDCN2_LCDMX_duty3      / LCDCN2_LCDMX_duty4                             |
|         lcdbi     - [in] LCDCN1_LCDBI_Static     / LCDCN1_LCDBI_Reserved                         |
|                          LCDCN1_LCDBI_BIAS       / LCDCN1_LCDBI_Unused                           |
|                                                                                                  |
|  Returns:                                                                                        |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                    |
|         This function is used to open the LCD driving circuit                                    |
|-------------------------------------------------------------------------------------------------*/
void LCD_Open(unsigned char lcdpr,      //LCD charge pump circuit controller
              unsigned char ckdiv,      //Prescaler of LCD peripheral operating frequency
              unsigned char vlcdx,      //Charge pump voltage state select controller
              unsigned char lcdmx,      //LCD Waveform output controller
              unsigned char lcdbi)      //LCD waveform bias controller
{
    CLK_LCDCKSel(ckdiv);
    LCD_DutyMode(lcdmx);
    LCD_ChargePumpConfig(lcdpr);
    LCD_ChargePumpSelect(vlcdx);
    LCD_BiasInput(lcdbi);
    LCD_OutBufferEnable();
    LCD_Enable();
}

/**************************************************************************************************|
|*  Static Functions                                                                              *|
|**************************************************************************************************/
