/**************************************************************************************************|
|* Copyright 2016 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|* - Generic Peripheral Library: A general and functional Interface for the specific Peripheral   *|
|* - Low Level Peripheral Access: Register-Bits Level access Macro, user must take care           *|
|*   of calling procedure and hardware constraints                                                *|
|* - Support Target: HY11P Series                                                                 *|
|**************************************************************************************************/
#include <CLK.h>           // CLK Cpnfig for LCD

/**************************************************************************************************|
|*                               Peripheral Register Bits field                                   *|
|**************************************************************************************************/
// LCDCN1 //
#define LCDCN1_ENLCD                     7
#define LCDCN1_ENLCD_MSK                (1 << LCDCN1_ENLCD)
#define LCDCN1_ENLCD_ENABLE             (1 << LCDCN1_ENLCD)
#define LCDCN1_ENLCD_DISABLE            (0 << LCDCN1_ENLCD)

#define LCDCN1_LCDPR                     6
#define LCDCN1_LCDPR_MSK                (1 << LCDCN1_LCDPR)
#define LCDCN1_LCDPR_INTERNAL           (1 << LCDCN1_LCDPR)
#define LCDCN1_LCDPR_EXTERNAL           (0 << LCDCN1_LCDPR)

#define LCDCN1_VLCDX                     4
#define LCDCN1_VLCDX_MSK                (3 << LCDCN1_VLCDX)
#define LCDCN1_VLCDX_2V55               (3 << LCDCN1_VLCDX)
#define LCDCN1_VLCDX_2V8                (2 << LCDCN1_VLCDX)
#define LCDCN1_VLCDX_3V05               (1 << LCDCN1_VLCDX)
#define LCDCN1_VLCDX_3V3                (0 << LCDCN1_VLCDX)

#define LCDCN1_LCDBF                     3
#define LCDCN1_LCDBF_MSK                (1 << LCDCN1_LCDBF)
#define LCDCN1_LCDBF_ENABLE             (1 << LCDCN1_LCDBF)
#define LCDCN1_LCDBF_DISABLE            (0 << LCDCN1_LCDBF)

#define LCDCN1_LCDBI                     1
#define LCDCN1_LCDBI_MSK                (3 << LCDCN1_LCDBI)
#define LCDCN1_LCDBI_Unused             (3 << LCDCN1_LCDBI)
#define LCDCN1_LCDBI_BIAS               (2 << LCDCN1_LCDBI)
#define LCDCN1_LCDBI_Reserved           (1 << LCDCN1_LCDBI)
#define LCDCN1_LCDBI_Static             (0 << LCDCN1_LCDBI)

// LCDCN2 //
#define LCDCN2_LCDBL                     7
#define LCDCN2_LCDBL_MSK                (1 << LCDCN2_LCDBL)
#define LCDCN2_LCDBL_LCDOFF             (1 << LCDCN2_LCDBL)
#define LCDCN2_LCDBL_LCDON              (0 << LCDCN2_LCDBL)

#define LCDCN2_LCDMX                     5
#define LCDCN2_LCDMX_MSK                (3 << LCDCN2_LCDMX)
#define LCDCN2_LCDMX_Static             (0 << LCDCN2_LCDMX)   //Static status (COM0)
#define LCDCN2_LCDMX_duty2              (1 << LCDCN2_LCDMX)   //1/2 duty (COM0, COM1)??At this time, COM3=SEG1??COM2=SEG0
#define LCDCN2_LCDMX_duty3              (2 << LCDCN2_LCDMX)   //1/3 duty (COM0, COM1, COM2)??At this time, COM3=SEG1
#define LCDCN2_LCDMX_duty4              (3 << LCDCN2_LCDMX)   //1/4 duty (COM0, COM1, COM2, COM3)

/**************************************************************************************************|
|*                                      Function Level                                            *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function-like Macro:                                                                            |
|    Register Bits field Configuration without function call overhead,                             |
|    user should take care of detail of h/w behavior and constrains.                               |
|-------------------------------------------------------------------------------------------------*/
#define LCD_Enable()                    (LCDCN1 |= LCDCN1_ENLCD_ENABLE)
#define LCD_Disable()                   (LCDCN1 &= (~LCDCN1_ENLCD_MSK))
#define LCD_OutBufferEnable()           (LCDCN1 |= LCDCN1_LCDBF_ENABLE)
#define LCD_OutBufferDisable()          (LCDCN1 &= (~LCDCN1_LCDBF_MSK))
#define LCD_DisplayOn()                 (LCDCN2 &= (~LCDCN2_LCDBL_MSK))
#define LCD_DisplayOff()                (LCDCN2 |= LCDCN2_LCDBL_LCDOFF)

#define LCD_CLKSel(ClkSel)              (MCKCN3 = ((MCKCN3 & (~MCKCN3_LCDS_MSK)) | ClkSel))
#define LCD_ChargePumpConfig(PRSel)     (LCDCN1 = ((LCDCN1 & (~LCDCN1_LCDPR_MSK)) | PRSel))
#define LCD_ChargePumpSelect(VLCDSel)   (LCDCN1 = ((LCDCN1 & (~LCDCN1_VLCDX_MSK)) | VLCDSel))
#define LCD_BiasInput(BISel)            (LCDCN1 = ((LCDCN1 & (~LCDCN1_LCDBI_MSK)) | BISel))
#define LCD_DutyMode(LCDMX)             (LCDCN2 = ((LCDCN2 & (~LCDCN2_LCDMX_MSK)) | LCDMX))

#define LCD_WriteData(uAddr,uData)      (*uAddr=uData)
#define LCD_ReadData(uAddr)             (*(uAddr))
/*-------------------------------------------------------------------------------------------------|
|  Function call:                                                                                  |
|    For general and functional register access.                                                   |
|-------------------------------------------------------------------------------------------------*/
void LCD_Open(unsigned char lcdpr,      //LCD charge pump circuit controller
              unsigned char ckdiv,      //Prescaler of LCD peripheral operating frequency
              unsigned char vlcdx,      //Charge pump voltage state select controller
              unsigned char lcdmx,      //LCD Waveform output controller
              unsigned char lcdbi);     //LCD waveform bias controller
 