/**************************************************************************************************|
|* Copyright 2016 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|* - Generic Peripheral Library: A general and functional Interface for the specific Peripheral   *|
|* - Low Level Peripheral Access: Register-Bits Level access Macro, user must take care           *|
|*   of calling procedure and hardware constraints                                                *|
|* - Support Target: HY11P Series                                                                 *|
|**************************************************************************************************/
#include <ADC.h>

/**************************************************************************************************|
|*                               Peripheral Register Bits field                                   *|
|**************************************************************************************************/
// OPCN1 //
#define OPCN1_ENOP                       7
#define OPCN1_ENOP_MSK                  (1 << OPCN1_ENOP)
#define OPCN1_ENOP_ENABLE               (1 << OPCN1_ENOP)
#define OPCN1_ENOP_DISABLE              (0 << OPCN1_ENOP)

#define OPCN1_OPM                        5
#define OPCN1_OPM_MSK                   (3 << OPCN1_OPM)
#define OPCN1_OPM_REVERSE               (3 << OPCN1_OPM)
#define OPCN1_OPM_FORWARD               (2 << OPCN1_OPM)
#define OPCN1_OPM_CHOPPER128            (1 << OPCN1_OPM)
#define OPCN1_OPM_CHOPPER64             (0 << OPCN1_OPM)

#define OPCN1_OPP                        3
#define OPCN1_OPP_MSK                   (3 << OPCN1_OPP)
#define OPCN1_OPP_AI11                  (3 << OPCN1_OPP)
#define OPCN1_OPP_AI10                  (2 << OPCN1_OPP)
#define OPCN1_OPP_AI7                   (1 << OPCN1_OPP)
#define OPCN1_OPP_AI3                   (0 << OPCN1_OPP)

#define OPCN1_OPN                        0
#define OPCN1_OPN_MSK                   (7 << OPCN1_OPN)
#define OPCN1_OPN_AI1                   (5 << OPCN1_OPN)   //AI1 and AI5 short but not short with AI0
#define OPCN1_OPN_AI0                   (4 << OPCN1_OPN)   //AI0 and AI5 short but not short with AI1
#define OPCN1_OPN_AI6                   (3 << OPCN1_OPN)
#define OPCN1_OPN_AI5                   (2 << OPCN1_OPN)
#define OPCN1_OPN_AI4                   (1 << OPCN1_OPN)
#define OPCN1_OPN_OPO                   (0 << OPCN1_OPN)

/**************************************************************************************************|
|*                                      Function Level                                            *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function-like Macro:                                                                            |
|    Register Bits field Configuration without function call overhead,                             |
|    user should take care of detail of h/w behavior and constrains.                               |
|-------------------------------------------------------------------------------------------------*/
#define LNOP1_Enable()                  (OPCN1 |= OPCN1_ENOP_ENABLE)
#define LNOP1_Disable()                 (OPCN1 &= (~OPCN1_ENOP_MSK))

#define LNOP1_OPMode(ModeSel)           (OPCN1 = ((OPCN1 & (~OPCN1_OPM_MSK)) | ModeSel))
#define LNOP1_OPChanIn(OPISel)          (AINET1 = ((AINET1 & (~AINET1_OPIS_MSK)) | OPISel))
#define LNOP1_OPInputP(OPPSel)          (OPCN1 = ((OPCN1 & (~OPCN1_OPP_MSK)) | OPPSel))
#define LNOP1_OPInputN(OPNSel)          (OPCN1 = ((OPCN1 & (~OPCN1_OPN_MSK)) | OPNSel))

/*-------------------------------------------------------------------------------------------------|
|  Function call:                                                                                  |
|    For general and functional register access.                                                   |
|-------------------------------------------------------------------------------------------------*/
void LNOP1_Open(unsigned char NInput,   //LNOP1 - end input channel selector
                unsigned char PInput,   //LNOP1 + end input channel selector
                unsigned char Chop);    //LNOP1 input processor
