/**************************************************************************************************|
|* Copyright 2016 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|* - Generic Peripheral Library: A general and functional Interface for the specific Peripheral   *|
|* - Low Level Peripheral Access: Register-Bits Level access Macro, user must take care           *|
|*   of calling procedure and hardware constraints                                                *|
|* - Support Target: HY11P Series                                                                 *|
|**************************************************************************************************/

/**************************************************************************************************|
|*                               Peripheral Register Bits field                                   *|
|**************************************************************************************************/
// OPCN2 //
#define OPCN2_ENOP2                      7
#define OPCN2_ENOP2_MSK                 (1 << OPCN2_ENOP2)
#define OPCN2_ENOP2_ENABLE              (1 << OPCN2_ENOP2)
#define OPCN2_ENOP2_DISABLE             (0 << OPCN2_ENOP2)

#define OPCN2_OPM2                       5
#define OPCN2_OPM2_MSK                  (3 << OPCN2_OPM2)
#define OPCN2_OPM2_REVERSE              (3 << OPCN2_OPM2)
#define OPCN2_OPM2_FORWARD              (2 << OPCN2_OPM2)
#define OPCN2_OPM2_CHOPPER128           (1 << OPCN2_OPM2)
#define OPCN2_OPM2_CHOPPER64            (0 << OPCN2_OPM2)

#define OPCN2_OPIS2                      4
#define OPCN2_OPIS2_MSK                 (1 << OPCN2_OPIS2)
#define OPCN2_OPIS2_ENABLE              (1 << OPCN2_OPIS2)
#define OPCN2_OPIS2_DISABLE             (0 << OPCN2_OPIS2)

#define OPCN2_OPP2                       2
#define OPCN2_OPP2_MSK                  (3 << OPCN2_OPP2)
#define OPCN2_OPP2_AI2                  (3 << OPCN2_OPP2)   //AI2 and AI11 short
#define OPCN2_OPP2_AI10                 (2 << OPCN2_OPP2)   //AI10 and AI11 short
#define OPCN2_OPP2_AI9                  (1 << OPCN2_OPP2)   //AI9 and AI11 short
#define OPCN2_OPP2_AI3                  (0 << OPCN2_OPP2)

#define OPCN2_OPN2                       0
#define OPCN2_OPN2_MSK                  (3 << OPCN2_OPN2)
#define OPCN2_OPN2_AI1                  (3 << OPCN2_OPN2)   //AI1 and AI5 short
#define OPCN2_OPN2_AI0                  (2 << OPCN2_OPN2)   //AI0 and AI5 short
#define OPCN2_OPN2_AI4                  (1 << OPCN2_OPN2)
#define OPCN2_OPN2_OPO2                 (0 << OPCN2_OPN2)

/**************************************************************************************************|
|*                                      Function Level                                            *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function-like Macro:                                                                            |
|    Register Bits field Configuration without function call overhead,                             |
|    user should take care of detail of h/w behavior and constrains.                               |
|-------------------------------------------------------------------------------------------------*/
#define LNOP2_Enable()                  (OPCN2 |= OPCN2_ENOP2_ENABLE)
#define LNOP2_Disable()                 (OPCN2 &= (~OPCN2_ENOP2_MSK))

#define LNOP2_OPChanIn(OPISel)          (OPCN2 = ((OPCN2 & (~OPCN2_OPIS2_MSK)) | OPISel))
#define LNOP2_OPMode(ModeSel)           (OPCN2 = ((OPCN2 & (~OPCN2_OPM2_MSK)) | ModeSel))
#define LNOP2_OPInputP(OPPSel)          (OPCN2 = ((OPCN2 & (~OPCN2_OPP2_MSK)) | OPPSel))
#define LNOP2_OPInputN(OPNSel)          (OPCN2 = ((OPCN2 & (~OPCN2_OPN2_MSK)) | OPNSel))

/*-------------------------------------------------------------------------------------------------|
|  Function call:                                                                                  |
|    For general and functional register access.                                                   |
|-------------------------------------------------------------------------------------------------*/
void LNOP2_Open(unsigned char NInput,   //LNOP2 - end input channel selector
                unsigned char PInput,   //LNOP2 + end input channel selector
                unsigned char Chop);    //LNOP2 input processor
