/**************************************************************************************************|
|* Copyright 2016 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|*                                                                                                *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Includes                                                                                      *|
|**************************************************************************************************/
#include <hy11s14sfr.h>    // Peripheral Register Memory Mapping
#include <PWM.h>
#include <GPIO.h>
/**************************************************************************************************|
|*  Static Function                                                                               *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Generic Peripheral Library                                                                    *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function: PFD_Open                                                                              |
|                                                                                                  |
|  Parameters:                                                                                     |
|         prc       - [in] PRC Setting                                                             |
|                                                                                                  |
|  Returns:                                                                                        |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                    |
|         This function is used to open the PFD                                                    |
|-------------------------------------------------------------------------------------------------*/
void PFD_Open(unsigned char prc)             //PRC Setting
{
  PRC=prc;
  GPIO_PT2OutputMode(TRISC2_TC22_OUTPUT);
  GPIO_PM22Sel(PT2M1_PM22_PFD);
  PFD_Enable();
}

/*-------------------------------------------------------------------------------------------------|
|  Function: PWM_Open                                                                              |
|                                                                                                  |
|  Parameters:                                                                                     |
|         mode      - [in] PWMCN_PWMCG_SINGLE / PWMCN_PWMCG_FULL                                   |
|                          PWMCN_PWMCG_HALF   / PWMCN_PWMCG_REVERSE                                |
|         state     - [in] PWMCN_PWMM_M0      / PWMCN_PWMM_M1                                      |
|                          PWMCN_PWMM_M2   / PWMCN_PWMM_M3                                         |
|         prc       - [in] PRC Setting                                                             |
|         pwmr      - [in] PWMR Setting                                                            |
|         dbd       - [in] PDBD Setting                                                            |
|                                                                                                  |
|  Returns:                                                                                        |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                    |
|         This function is used to open the Pulse Width Modulation(PWM)                            |
|-------------------------------------------------------------------------------------------------*/
void PWM_Open(unsigned char mode,            //Output Mode
              unsigned char state,           //Output State Select
              unsigned char prc,             //PRC Setting
              unsigned  int pwmr,            //PWMR Setting
              unsigned char dbd)             //PDBD Setting
{
  PWM_OutMode(mode);
  if (mode==PWMCN_PWMCG_SINGLE)
  {
    GPIO_PT2OutputMode(0b00000100);
    GPIO_PM22Sel(PT2M1_PM22_PWM0);
  }
  else if (mode==PWMCN_PWMCG_HALF)
  {
    GPIO_PT2OutputMode(0b00001100);
    GPIO_PM22Sel(PT2M1_PM22_PWM0);
    GPIO_PM23Sel(PT2M1_PM23_PWM1);
  }
  else
  {
    GPIO_PT2OutputMode(0b00111100);
    GPIO_PM22Sel(PT2M1_PM22_PWM0);
    GPIO_PM23Sel(PT2M1_PM23_PWM1);
    GPIO_PM24Sel(PT2M2_PM24_PWM2);
    GPIO_PM25Sel(PT2M2_PM25_PWM3);
  }
  PWM_OutStateSelect(state);
  PRC=prc;
  PWM_DBDTime(dbd);
  PWM_PWMRH(pwmr>>2);
  PWM_PWMRL((pwmr<<4)&0x30);
  PWM_Enable();
}

/**************************************************************************************************|
|*  Static Functions                                                                              *|
|**************************************************************************************************/
