/**************************************************************************************************|
|* Copyright 2016 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|* - Generic Peripheral Library: A general and functional Interface for the specific Peripheral   *|
|* - Low Level Peripheral Access: Register-Bits Level access Macro, user must take care           *|
|*   of calling procedure and hardware constraints                                                *|
|* - Support Target: HY11P Series                                                                 *|
|**************************************************************************************************/

/**************************************************************************************************|
|*                               Peripheral Register Bits field                                   *|
|**************************************************************************************************/
// PASC //
#define PASC_PASF                        7
#define PASC_PASF_MSK                   (1 << PASC_PASF)
#define PASC_PASF_SHUTOFF               (1 << PASC_PASF)   //PWMx auto shutoff status pinout
#define PASC_PASF_NORMAL                (0 << PASC_PASF)   //PWM normal modulation output

#define PASC_PASCF                       4
#define PASC_PASCF_MSK                  (3 << PASC_PASCF)
#define PASC_PASCF_CPAO                 (3 << PASC_PASCF)   //Enhanced Comparator output
#define PASC_PASCF_MIX                  (2 << PASC_PASCF)   //FIL0 or CPAO
#define PASC_PASCF_FIL0                 (1 << PASC_PASCF)   //
#define PASC_PASCF_CLOSE                (0 << PASC_PASCF)   //Auto shutoff event

#define PASC_PSSCN0                      2                  //PWM0 and PWM2 Pins Auto shutoff pinout defined controller
#define PASC_PSSCN0_MSK                 (3 << PASC_PSSCN0)
#define PASC_PSSCN0_OTHER               (3 << PASC_PSSCN0)   //pinout is other combination status
#define PASC_PSSCN0_HIGH                (1 << PASC_PSSCN0)   //pinout is high state
#define PASC_PSSCN0_LOW                 (0 << PASC_PSSCN0)   //pinout is low state

#define PASC_PSSCN1                      0                  //PWM0 and PWM2 Pins Auto shutoff pinout defined controller
#define PASC_PSSCN1_MSK                 (3 << PASC_PSSCN1)
#define PASC_PSSCN1_OTHER               (3 << PASC_PSSCN1)   //pinout is other combination status
#define PASC_PSSCN1_HIGH                (1 << PASC_PSSCN1)   //pinout is high state
#define PASC_PSSCN1_LOW                 (0 << PASC_PSSCN1)   //pinout is low state

// PWMCN //
#define PWMCN_ENPWM                      7
#define PWMCN_ENPWM_MSK                 (1 << PWMCN_ENPWM)
#define PWMCN_ENPWM_ENABLE              (1 << PWMCN_ENPWM)
#define PWMCN_ENPWM_DISABLE             (0 << PWMCN_ENPWM)

#define PWMCN_ENPFD                      6
#define PWMCN_ENPFD_MSK                 (1 << PWMCN_ENPFD)
#define PWMCN_ENPFD_ENABLE              (1 << PWMCN_ENPFD)
#define PWMCN_ENPFD_DISABLE             (0 << PWMCN_ENPFD)

#define PWMCN_PWMRL                      4
#define PWMCN_PWMRL_MSK                 (3 << PWMCN_PWMRL)

#define PWMCN_PWMCG                      2
#define PWMCN_PWMCG_MSK                 (3 << PWMCN_PWMCG)
#define PWMCN_PWMCG_REVERSE             (3 << PWMCN_PWMCG)
#define PWMCN_PWMCG_HALF                (2 << PWMCN_PWMCG)
#define PWMCN_PWMCG_FULL                (1 << PWMCN_PWMCG)
#define PWMCN_PWMCG_SINGLE              (0 << PWMCN_PWMCG)

#define PWMCN_PWMM                       0
#define PWMCN_PWMM_MSK                  (3 << PWMCN_PWMM)
#define PWMCN_PWMM_M3                   (3 << PWMCN_PWMM)   //PWM0 and PWM2 is active low state, PWM1 and PWM3 are active low state
#define PWMCN_PWMM_M2                   (2 << PWMCN_PWMM)   //PWM0 and PWM2 is active low state, PWM1 and PWM3 are active high state
#define PWMCN_PWMM_M1                   (1 << PWMCN_PWMM)   //PWM0 and PWM2 is active high state, PWM1 and PWM3 are active low state
#define PWMCN_PWMM_M0                   (0 << PWMCN_PWMM)   //PWM0 and PWM2 is active high state, PWM1 and PWM3 are active high state

// PDBD //
#define PDBD_ENPRS                       7
#define PDBD_ENPRS_MSK                  (1 << PDBD_ENPRS)
#define PDBD_ENPRS_AUTO                 (1 << PDBD_ENPRS)
#define PDBD_ENPRS_USER                 (0 << PDBD_ENPRS)

#define PDBD_DBDC                        0
#define PDBD_DBDC_MSK                   (127 << PDBD_DBDC)

/**************************************************************************************************|
|*                                      Function Level                                            *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function-like Macro:                                                                            |
|    Register Bits field Configuration without function call overhead,                             |
|    user should take care of detail of h/w behavior and constrains.                               |
|-------------------------------------------------------------------------------------------------*/
#define PFD_Enable()                    (PWMCN |= PWMCN_ENPFD_ENABLE)
#define PFD_Disable()                   (PWMCN &= (~PWMCN_ENPFD_MSK))
#define PWM_Enable()                    (PWMCN |= PWMCN_ENPWM_ENABLE)
#define PWM_Disable()                   (PWMCN &= (~PWMCN_ENPWM_MSK))

#define PWM_ShutoffEnable()             (PASC |= PASC_PASF_SHUTOFF)//ERROR: change'PWMCN_ENPFD_ENABLE' to 'PASC_PASF_SHUTOFF' 2017/9/6  
#define PWM_ShutoffDisable()            (PASC &= (~PASC_PASF_MSK))

#define PWM_ShutoffConfig(SCFCon)       (PASC = ((PASC & (~PASC_PASCF_MSK)) | SCFCon))
#define PWM_ShutoffDefine0(SCN0Sel)     (PASC = ((PASC & (~PASC_PSSCN0_MSK)) | SCN0Sel))
#define PWM_ShutoffDefine1(SCN1Sel)     (PASC = ((PASC & (~PASC_PSSCN1_MSK)) | SCN1Sel))
#define PWM_OutMode(CGSel)              (PWMCN = ((PWMCN & (~PWMCN_PWMCG_MSK)) | CGSel))
#define PWM_OutStateSelect(MSel)        (PWMCN = ((PWMCN & (~PWMCN_PWMM_MSK)) | MSel))
#define PWM_StartConfig(PRSCon)         (PDBD = ((PDBD & (~PDBD_ENPRS_MSK)) | PRSCon))
#define PWM_DBDTime(DBDCSel)            (PDBD = ((PDBD & (~PDBD_DBDC_MSK)) | DBDCSel))
#define PWM_PWMRL(RLSel)                (PWMCN = ((PWMCN & (~PWMCN_PWMRL_MSK)) | RLSel))
#define PWM_PWMRH(RHSel)                (PWMR = RHSel)

/*-------------------------------------------------------------------------------------------------|
|  Function call:                                                                                  |
|    For general and functional register access.                                                   |
|-------------------------------------------------------------------------------------------------*/
void PFD_Open(unsigned char prc);       //PRC Setting


void PWM_Open(unsigned char mode,       //Output Mode
              unsigned char state,      //Output State Select
              unsigned char prc,        //PRC Setting
              unsigned  int pwmr,       //PWMR Setting
              unsigned char dbd);       //PDBD Setting
