/**************************************************************************************************|
|* Copyright 2016 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|*                                                                                                *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Includes                                                                                      *|
|**************************************************************************************************/
#include <hy11s14sfr.h>    // Peripheral Register Memory Mapping
#include <SPI.h>
#include <GPIO.h>

/**************************************************************************************************|
|*  Static Function                                                                               *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Generic Peripheral Library                                                                    *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function: SPI_Open                                                                              |
|                                                                                                  |
|  Parameters:                                                                                     |
|         sspm      - [in] SSPCON1_SSPM_LSCK                                                       |
|                          SSPCON1_SSPM_CPUCK                                                      |
|                          SSPCON1_SSPM_SCK       *AI0 and AI5 short*                              |
|                          SSPCON1_SSPM_4WIRE     *AI1 and AI5 short*                              |
|         ckp       - [in] SSPCON1_CKP_HI                                                          |
|                          SSPCON1_CKP_LOW                                                         |
|         cke       - [in] SSPCON1_CKE_IDLE                                                        |
|                          SSPCON1_CKE_EFFECTIVE                                                   |
|         smp       - [in] SSPCON1_SMP_MASTEREND                                                   |
|                          SSPCON1_SMP_MASTERMID                                                   |
|                          SSPCON1_SMP_SLAVE                                                       |
|                                                                                                  |
|  Returns:                                                                                        |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                    |
|         This function is used to open the Serial Peripheral Interface(SPI)                       |
|-------------------------------------------------------------------------------------------------*/
void SPI_Open(unsigned char sspm,  //SPI mode select
              unsigned char ckp,   //SPI clock source polarity select bit
              unsigned char cke,   //SPI clock source select bit
              unsigned char smp)  //SPI sample bit
{
    PT1DA &= (~PT1DA_DA12_MSK);
    PT1M2 |= PT1M2_PM15_SDO;
    TRISC1 |= TRISC1_TC15_OUTPUT;
    PT1M2 |= PT1M2_PM16_SCK;
    if(sspm==0x03)
      PT1DA &= (~PT1DA_DA11_MSK);
    SPI_Enable();
    SPI_Mode(sspm);
    SPI_CLKIdleConfig(ckp);
    SPI_CLKConfig(cke);
    SPI_MasterMode(smp);
}

/**************************************************************************************************|
|*  Static Functions                                                                              *|
|**************************************************************************************************/
