/**************************************************************************************************|
|* Copyright 2016 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|* - Generic Peripheral Library: A general and functional Interface for the specific Peripheral   *|
|* - Low Level Peripheral Access: Register-Bits Level access Macro, user must take care           *|
|*   of calling procedure and hardware constraints                                                *|
|* - Support Target: HY11P Series                                                                 *|
|**************************************************************************************************/
#include <INT.h>           // Interrupt Config for WDT

/**************************************************************************************************|
|*                               Peripheral Register Bits field                                   *|
|**************************************************************************************************/
// SSPCON1 //
#define SSPCON1_SSPEN                    7
#define SSPCON1_SSPEN_MSK               (1 << SSPCON1_SSPEN)
#define SSPCON1_SSPEN_ENABLE            (1 << SSPCON1_SSPEN)
#define SSPCON1_SSPEN_DISABLE           (0 << SSPCON1_SSPEN)

#define SSPCON1_CKP                      6
#define SSPCON1_CKP_MSK                 (1 << SSPCON1_CKP)
#define SSPCON1_CKP_HI                  (1 << SSPCON1_CKP)   //Configure high state clock source as idle status
#define SSPCON1_CKP_LOW                 (0 << SSPCON1_CKP)   //Configure low state clock source as idle status

#define SSPCON1_CKE                      5
#define SSPCON1_CKE_MSK                 (1 << SSPCON1_CKE)
#define SSPCON1_CKE_IDLE                (1 << SSPCON1_CKE)   //Transmit when clock changes from effective status to idle status
#define SSPCON1_CKE_EFFECTIVE           (0 << SSPCON1_CKE)   //Transmit when clock changes from idle status to effective status

#define SSPCON1_SMP                      4
#define SSPCON1_SMP_MSK                 (1 << SSPCON1_SMP)
#define SSPCON1_SMP_MASTEREND           (1 << SSPCON1_SMP)   //Master, Sampling input data at the end
#define SSPCON1_SMP_MASTERMID           (0 << SSPCON1_SMP)   //Master, Sampling input data in the middle
#define SSPCON1_SMP_SLAVE               (0 << SSPCON1_SMP)   //Slave, Users must clear SMP BIT as 0

#define SSPCON1_SSPM                     0
#define SSPCON1_SSPM_MSK                (3 << SSPCON1_SSPM)
#define SSPCON1_SSPM_LSCK               (0 << SSPCON1_SSPM)   //Master, clock source = LS_CK
#define SSPCON1_SSPM_CPUCK              (1 << SSPCON1_SSPM)   //Master, clock source = CPU_CK
#define SSPCON1_SSPM_SCK                (2 << SSPCON1_SSPM)   //Slave, 3wire mode
#define SSPCON1_SSPM_4WIRE              (3 << SSPCON1_SSPM)   //Slave, 4wire mode

// SSPSTA //
#define SSPSTA_SSPBUY                    7                     //only for data transmission use
#define SSPSTA_SSPBUY_MSK               (1 << SSPSTA_SSPBUY)
#define SSPSTA_SSPBUY_TRANSMITTING      (1 << SSPSTA_SSPBUY)   //The data is still in transmitting status
#define SSPSTA_SSPBUY_NOCOLLISION       (0 << SSPSTA_SSPBUY)   //No collision

#define SSPSTA_SSPOV                     6
#define SSPSTA_SSPOV_MSK                (1 << SSPSTA_SSPOV)
#define SSPSTA_SSPOV_OVERFLOW           (1 << SSPSTA_SSPOV)
#define SSPSTA_SSPOV_NOOVERFLOW         (0 << SSPSTA_SSPOV)

#define SSPSTA_BF                        0
#define SSPSTA_BF_MSK                   (1 << SSPSTA_BF)
#define SSPSTA_BF_FULL                  (1 << SSPSTA_BF)   //Reception accomplished, SSPBUF is full
#define SSPSTA_BF_EMPTY                 (0 << SSPSTA_BF)   //Reception not accomplished, SSPBUF is empty

/**************************************************************************************************|
|*                                      Function Level                                            *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function-like Macro:                                                                            |
|    Register Bits field Configuration without function call overhead,                             |
|    user should take care of detail of h/w behavior and constrains.                               |
|-------------------------------------------------------------------------------------------------*/
#define SPI_INT_Enable()                (INTE2 |= INTE2_SSPIE_ENABLE)
#define SPI_INT_Disable()               (INTE2 &= (~INTE2_SSPIE_MSK))//error: use wrong register'INTF2',change to 'INTE2' 2017/07/21
#define SPI_INT_IsFlag()                (INTF2 & INTF2_SSPIF_SET)
#define SPI_INT_ClearFlag()             (INTF2 &= (~INTF2_SSPIF_MSK))

#define SPI_Enable()                    (SSPCON1 |= SSPCON1_SSPEN_ENABLE)
#define SPI_Disable()                   (SSPCON1 &= (~SSPCON1_SSPEN_MSK))//error:use wrong register'SPCON1',change to 'SSPCON1';2017/07/21

#define SPI_CLKIdleConfig(IdleCon)      (SSPCON1 = ((SSPCON1 & (~SSPCON1_CKP_MSK)) | IdleCon))
#define SPI_CLKConfig(CLKCon)           (SSPCON1 = ((SSPCON1 & (~SSPCON1_CKE_MSK)) | CLKCon))
#define SPI_MasterMode(MModeCon)        (SSPCON1 = ((SSPCON1 & (~SSPCON1_SMP_MSK)) | MModeCon))
#define SPI_SlaveMode()                 (SSPCON1 &= (~SSPCON1_SMP_MSK))
#define SPI_Mode(SSPMSel)               (SSPCON1 = ((SSPCON1 & (~SSPCON1_SSPM_MSK)) | SSPMSel))
#define SPI_BUYCheck()                  (SSPSTA & SSPSTA_SSPBUY_TRANSMITTING)
#define SPI_BFCheck()                   (SSPSTA & SSPSTA_BF_FULL)
#define SPI_ClearPOV()                  (SSPSTA &= (~SSPSTA_SSPOV_MSK))

/*-------------------------------------------------------------------------------------------------|
|  Function call:                                                                                  |
|    For general and functional register access.                                                   |
|-------------------------------------------------------------------------------------------------*/
void SPI_Open(unsigned char sspm,       //SPI mode select
              unsigned char ckp,        //SPI clock source polarity select bit
              unsigned char cke,        //SPI clock source select bit
              unsigned char smp);       //SPI sample bit
