/**************************************************************************************************|
|* Copyright 2016 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|* - Generic Peripheral Library: A general and functional Interface for the specific Peripheral   *|
|* - Low Level Peripheral Access: Register-Bits Level access Macro, user must take care           *|
|*   of calling procedure and hardware constraints                                                *|
|* - Support Target: HY11P Series                                                                 *|
|**************************************************************************************************/
#include <INT.h>           // Interrupt Config for TMA

/**************************************************************************************************|
|*                               Peripheral Register Bits field                                   *|
|**************************************************************************************************/
// TMACN //
#define TMACN_ENTMA                      7
#define TMACN_ENTMA_MSK                 (1 << TMACN_ENTMA)
#define TMACN_ENTMA_ENABLE              (1 << TMACN_ENTMA)
#define TMACN_ENTMA_DISABLE             (0 << TMACN_ENTMA)

#define TMACN_TMACK                      6
#define TMACN_TMACK_MSK                 (1 << TMACN_TMACK)
#define TMACN_TMACK_DIV1                (1 << TMACN_TMACK)
#define TMACN_TMACK_DIV256              (0 << TMACN_TMACK)

#define TMACN_TMAS                       4
#define TMACN_TMAS_MSK                  (3 << TMACN_TMAS)
#define TMACN_TMAS_DIV256               (3 << TMACN_TMAS)
#define TMACN_TMAS_DIV64                (2 << TMACN_TMAS)
#define TMACN_TMAS_DIV16                (1 << TMACN_TMAS)
#define TMACN_TMAS_DIV4                 (0 << TMACN_TMAS)

/**************************************************************************************************|
|*                                      Function Level                                            *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function-like Macro:                                                                            |
|    Register Bits field Configuration without function call overhead,                             |
|    user should take care of detail of h/w behavior and constrains.                               |
|-------------------------------------------------------------------------------------------------*/
#define TMA_INT_Enable()                (INTE1 |= INTE1_TMAIE_ENABLE)
#define TMA_INT_Disable()               (INTE1 &= (~INTE1_TMAIE_MSK))
#define TMA_INT_IsFlag()                (INTF1 & INTF1_TMAIF_SET)
#define TMA_INT_ClearFlag()             (INTF1 &= (~INTF1_TMAIF_MSK))

#define TMA_Enable()                    (TMACN |= TMACN_ENTMA_ENABLE)
#define TMA_Disable()                   (TMACN &= (~TMACN_ENTMA_MSK))
#define TMA_CLKSel(CLKSel)              (TMACN = ((TMACN & (~TMACN_TMACK_MSK)) | CLKSel))
#define TMA_OFControlSel(TMASel)        (TMACN = ((TMACN & (~TMACN_TMAS_MSK)) | TMASel))

/*-------------------------------------------------------------------------------------------------|
|  Function call:                                                                                  |
|    For general and functional register access.                                                   |
|-------------------------------------------------------------------------------------------------*/
void TMA_Open(unsigned char ck,         //Timer-A operating frequency selector
              unsigned char cks);       //Timer-A overflow controller
