/**************************************************************************************************|
|* Copyright 2016 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|* - Generic Peripheral Library: A general and functional Interface for the specific Peripheral   *|
|* - Low Level Peripheral Access: Register-Bits Level access Macro, user must take care           *|
|*   of calling procedure and hardware constraints                                                *|
|* - Support Target: HY11P Series                                                                 *|
|**************************************************************************************************/
#include <INT.h>           // Interrupt Config for TMB

/**************************************************************************************************|
|*                               Peripheral Register Bits field                                   *|
|**************************************************************************************************/
// TMBCN //
#define TMBCN_ENTMB                      7
#define TMBCN_ENTMB_MSK                 (1 << TMBCN_ENTMB)
#define TMBCN_ENTMB_ENABLE              (1 << TMBCN_ENTMB)
#define TMBCN_ENTMB_DISABLE             (0 << TMBCN_ENTMB)

#define TMBCN_TMBCK                      6
#define TMBCN_TMBCK_MSK                 (1 << TMBCN_TMBCK)
#define TMBCN_TMBCK_LSCK                (1 << TMBCN_TMBCK)
#define TMBCN_TMBCK_INTRCK              (0 << TMBCN_TMBCK)

#define TMBCN_TMBS                       4
#define TMBCN_TMBS_MSK                  (3 << TMBCN_TMBS)
#define TMBCN_TMBS_DIV8                 (3 << TMBCN_TMBS)
#define TMBCN_TMBS_DIV4                 (2 << TMBCN_TMBS)
#define TMBCN_TMBS_DIV2                 (1 << TMBCN_TMBS)
#define TMBCN_TMBS_DIV1                 (0 << TMBCN_TMBS)

#define TMBCN_TMBSYC                     3
#define TMBCN_TMBSYC_MSK                (1 << TMBCN_TMBSYC)
#define TMBCN_TMBSYC_SYNCH              (1 << TMBCN_TMBSYC)
#define TMBCN_TMBSYC_ASYNCH             (0 << TMBCN_TMBSYC)

#define TMBCN_TMBR2R                     2
#define TMBCN_TMBR2R_MSK                (1 << TMBCN_TMBR2R)
#define TMBCN_TMBR2R_16BIT              (1 << TMBCN_TMBR2R)
#define TMBCN_TMBR2R_8BIT               (0 << TMBCN_TMBR2R)

/**************************************************************************************************|
|*                                      Function Level                                            *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function-like Macro:                                                                            |
|    Register Bits field Configuration without function call overhead,                             |
|    user should take care of detail of h/w behavior and constrains.                               |
|-------------------------------------------------------------------------------------------------*/
#define TMB_INT_Enable()                (INTE1 |= INTE1_TMBIE_ENABLE)
#define TMB_INT_Disable()               (INTE1 &= (~INTE1_TMBIE_MSK))
#define TMB_INT_IsFlag()                (INTF1 & INTF1_TMBIF_SET)
#define TMB_INT_ClearFlag()             (INTF1 &= (~INTF1_TMBIF_MSK))

#define TMB_Enable()                    (TMBCN |= TMBCN_ENTMB_ENABLE)
#define TMB_Disable()                   (TMBCN &= (~TMBCN_ENTMB_MSK))

#define TMB_CLKSel(CLKSel)              (TMBCN = ((TMBCN & (~TMBCN_TMBCK_MSK)) | CLKSel))
#define TMB_CLKPrescalerSel(CLKPreSel)  (TMBCN = ((TMBCN & (~TMBCN_TMBS_MSK)) | CLKPreSel))
#define TMB_SynchConfig(SynchCon)       (TMBCN = ((TMBCN & (~TMBCN_TMBSYC_MSK)) | SynchCon))
#define TMB_TMBROperateMode(TMBRSel)    (TMBCN = ((TMBCN & (~TMBCN_TMBR2R_MSK)) | TMBRSel))

/*-------------------------------------------------------------------------------------------------|
|  Function call:                                                                                  |
|    For general and functional register access.                                                   |
|-------------------------------------------------------------------------------------------------*/
void TMB_Open(unsigned char ck,         //Timer-B operating frequency select controller
              unsigned char cks,        //Timer-B overflow controller
              unsigned char mode);      //TMBR register operating way
