/**************************************************************************************************|
|* Copyright 2016 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|* - Generic Peripheral Library: A general and functional Interface for the specific Peripheral   *|
|* - Low Level Peripheral Access: Register-Bits Level access Macro, user must take care           *|
|*   of calling procedure and hardware constraints                                                *|
|* - Support Target: HY11P Series                                                                 *|
|**************************************************************************************************/
#include <INT.h>           // Interrupt Config for TMC

/**************************************************************************************************|
|*                               Peripheral Register Bits field                                   *|
|**************************************************************************************************/
// TMCCN //
#define TMCCN_ENTMC                      7
#define TMCCN_ENTMC_MSK                 (1 << TMCCN_ENTMC)
#define TMCCN_ENTMC_ENABLE              (1 << TMCCN_ENTMC)
#define TMCCN_ENTMC_DISABLE             (0 << TMCCN_ENTMC)

#define TMCCN_TMCCK                      5
#define TMCCN_TMCCK_MSK                 (3 << TMCCN_TMCCK)
#define TMCCN_TMCCK_CPAO                (3 << TMCCN_TMCCK)
#define TMCCN_TMCCK_TMCKI               (2 << TMCCN_TMCCK)
#define TMCCN_TMCCK_LSCK                (1 << TMCCN_TMCCK)
#define TMCCN_TMCCK_INTRCK              (0 << TMCCN_TMCCK)

#define TMCCN_TMCS1                      2
#define TMCCN_TMCS1_MSK                 (7 << TMCCN_TMCS1)
#define TMCCN_TMCS1_DIV8                (7 << TMCCN_TMCS1)
#define TMCCN_TMCS1_DIV7                (6 << TMCCN_TMCS1)
#define TMCCN_TMCS1_DIV6                (5 << TMCCN_TMCS1)
#define TMCCN_TMCS1_DIV5                (4 << TMCCN_TMCS1)
#define TMCCN_TMCS1_DIV4                (3 << TMCCN_TMCS1)
#define TMCCN_TMCS1_DIV3                (2 << TMCCN_TMCS1)
#define TMCCN_TMCS1_DIV2                (1 << TMCCN_TMCS1)
#define TMCCN_TMCS1_DIV1                (0 << TMCCN_TMCS1)

#define TMCCN_TMCS0                      0
#define TMCCN_TMCS0_MSK                 (3 << TMCCN_TMCS0)
#define TMCCN_TMCS0_DIV16               (3 << TMCCN_TMCS0)
#define TMCCN_TMCS0_DIV4                (2 << TMCCN_TMCS0)
#define TMCCN_TMCS0_DIV2                (1 << TMCCN_TMCS0)
#define TMCCN_TMCS0_DIV1                (0 << TMCCN_TMCS0)

/**************************************************************************************************|
|*                                      Function Level                                            *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function-like Macro:                                                                            |
|    Register Bits field Configuration without function call overhead,                             |
|    user should take care of detail of h/w behavior and constrains.                               |
|-------------------------------------------------------------------------------------------------*/
#define TMC_INT_Enable()                (INTE1 |= INTE1_TMCIE_ENABLE)
#define TMC_INT_Disable()               (INTE1 &= (~INTE1_TMCIE_MSK))
#define TMC_INT_IsFlag()                (INTF1 & INTF1_TMCIF_SET)
#define TMC_INT_ClearFlag()             (INTF1 &= (~INTF1_TMCIF_MSK))

#define TMC_Enable()                    (TMCCN |= TMCCN_ENTMC_ENABLE)
#define TMC_Disable()                   (TMCCN &= (~TMCCN_ENTMC_MSK))

#define TMC_CLKSel(CLKSel)              (TMCCN = ((TMCCN & (~TMCCN_TMCCK_MSK)) | CLKSel))
#define TMC_OFControlSel(TMCSel1)       (TMCCN = ((TMCCN & (~TMCCN_TMCS1_MSK)) | TMCSel1))
#define TMC_CLKPrescalerSel(TMCSel0)    (TMCCN = ((TMCCN & (~TMCCN_TMCS0_MSK)) | TMCSel0))

/*-------------------------------------------------------------------------------------------------|
|  Function call:                                                                                  |
|    For general and functional register access.                                                   |
|-------------------------------------------------------------------------------------------------*/
void TMC_Open(unsigned char tmcck,      //TMC operating frequency select controller
              unsigned char tmcs0,      //Timer-C operating frequency prescaler
              unsigned char tmcs1);     //Timer-C counter overflow controller
