/**************************************************************************************************|
|* Copyright 2016 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|*                                                                                                *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Includes                                                                                      *|
|**************************************************************************************************/
#include <hy11s14sfr.h>    // Peripheral Register Memory Mapping
#include <UART.h>
#include <GPIO.h>

/**************************************************************************************************|
|*  Static Function                                                                               *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Generic Peripheral Library                                                                    *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function: UART_Open                                                                             |
|                                                                                                  |
|  Parameters:                                                                                     |
|         uBRGR     - [in] Desired baud rate.                                                      |
|         uDataBits - [in] "8"                 *8 bit mode*                                        |
|                          "9"                 *9 bit mode*                                        |
|         uParity   - [in] URCON_PARITY_Odd / URCON_PARITY_Even / URCON_PARITY_None                |
|                                                                                                  |
|  Returns:                                                                                        |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                    |
|         This function is used to open                                                            |
|                  the Enhanced Universal Asynchronous Receiver Transmitter(UART)                  |
|-------------------------------------------------------------------------------------------------*/
void UART_Open(unsigned int  uBRGR,     //desired baud rate
               unsigned char uDataBits, //Enable the transmission of the ninth bit
                                        //and send the ninth bit data
               unsigned char uParity)   //Odd/even bit check
{

    GPIO_PM14Sel(PT1M2_PM14_TX);        //Select TX function output
    GPIO_PT1OutputMode(TRISC1_TC14_OUTPUT);
    GPIO_PT1InputPullHight(PT1PU_PU14_ENABLE);
    GPIO_PT1InputPullHight(PT1PU_PU13_ENABLE);
    BRGRL = ((char *)(&uBRGR))[0];
    BRGRH = ((char *)(&uBRGR))[1];
    if (uDataBits==9)
    {
        UART_TX9Enable();
        UART_RC9Enable();
    }
    else
    {
        UART_TX9Disable();
        UART_RC9Disable();
    }
    UART_ParityCheck(uParity);
    UART_TXEnable();
    UART_DataReceiveEnable();
    UART_Enable();
}

/**************************************************************************************************|
|*  Static Functions                                                                              *|
|**************************************************************************************************/
