/**************************************************************************************************|
|* Copyright 2016 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|* - Generic Peripheral Library: A general and functional Interface for the specific Peripheral   *|
|* - Low Level Peripheral Access: Register-Bits Level access Macro, user must take care           *|
|*   of calling procedure and hardware constraints                                                *|
|* - Support Target: HY11P Series                                                                 *|
|**************************************************************************************************/
#include <INT.h>           // Interrupt Config for UART

/**************************************************************************************************|
|*                               Peripheral Register Bits field                                   *|
|**************************************************************************************************/
// URCON //
#define URCON_ENSP                       7
#define URCON_ENSP_MSK                  (1 << URCON_ENSP)
#define URCON_ENSP_ENABLE               (1 << URCON_ENSP)
#define URCON_ENSP_DISABLE              (0 << URCON_ENSP)

#define URCON_ENTX                       6
#define URCON_ENTX_MSK                  (1 << URCON_ENTX)
#define URCON_ENTX_ENABLE               (1 << URCON_ENTX)
#define URCON_ENTX_DISABLE              (1 << URCON_ENTX)

#define URCON_TX9                        5
#define URCON_TX9_MSK                   (1 << URCON_TX9)
#define URCON_TX9_ENABLE                (1 << URCON_TX9)
#define URCON_TX9_DISABLE               (0 << URCON_TX9)

#define URCON_TX9D                       4
#define URCON_TX9D_MSK                  (1 << URCON_TX9D)
#define URCON_TX9D_1                    (1 << URCON_TX9D)
#define URCON_TX9D_0                    (0 << URCON_TX9D)

#define URCON_PARITY                     3
#define URCON_PARITY_MSK                (1 << URCON_PARITY)
#define URCON_PARITY_Odd                (1 << URCON_PARITY)
#define URCON_PARITY_Even               (0 << URCON_PARITY)
#define URCON_PARITY_None               (0 << URCON_PARITY)

#define URCON_WUE                        0
#define URCON_WUE_MSK                   (1 << URCON_WUE)
#define URCON_WUE_ENABLE                (1 << URCON_WUE)
#define URCON_WUE_DISABLE               (0 << URCON_WUE)

// URSTA //
#define URSTA_RC9D                       6
#define URSTA_RC9D_MSK                  (1 << URSTA_RC9D)
#define URSTA_RC9D_1                    (1 << URSTA_RC9D)
#define URSTA_RC9D_0                    (0 << URSTA_RC9D)

#define URSTA_PERR                       5
#define URSTA_PERR_MSK                  (1 << URSTA_PERR)
#define URSTA_PERR_ERROR                (1 << URSTA_PERR)
#define URSTA_PERR_CORR                 (0 << URSTA_PERR)

#define URSTA_FERR                       4
#define URSTA_FERR_MSK                  (1 << URSTA_FERR)
#define URSTA_FERR_INCOMPLETE           (1 << URSTA_FERR)
#define URSTA_FERR_COMPLETE             (0 << URSTA_FERR)

#define URSTA_OERR                       3
#define URSTA_OERR_MSK                  (1 << URSTA_OERR)
#define URSTA_OERR_HAPPENED             (1 << URSTA_OERR)
#define URSTA_OERR_NOTHAPPENED          (0 << URSTA_OERR)

#define URSTA_RCIDL                      2
#define URSTA_RCIDL_MSK                 (1 << URSTA_RCIDL)
#define URSTA_RCIDL_RECEIVING           (1 << URSTA_RCIDL)
#define URSTA_RCIDL_NOTRECEIVING        (0 << URSTA_RCIDL)

#define URSTA_TRMT                       1
#define URSTA_TRMT_MSK                  (1 << URSTA_TRMT)
#define URSTA_TRMT_EMPTY                (1 << URSTA_TRMT)
#define URSTA_TRMT_DATA                 (0 << URSTA_TRMT)

#define URSTA_ABDOVF                     0
#define URSTA_ABDOVF_MSK                (1 << URSTA_ABDOVF)
#define URSTA_ABDOVF_HAPPENED           (1 << URSTA_ABDOVF)
#define URSTA_ABDOVF_NOTHAPPENED        (0 << URSTA_ABDOVF)

// BAUDCON //
#define BAUDCON_ENCR                     3
#define BAUDCON_ENCR_MSK                (1 << BAUDCON_ENCR)
#define BAUDCON_ENCR_ENABLE             (1 << BAUDCON_ENCR)
#define BAUDCON_ENCR_DISABLE            (0 << BAUDCON_ENCR)

#define BAUDCON_RC9                      2
#define BAUDCON_RC9_MSK                 (1 << BAUDCON_RC9)
#define BAUDCON_RC9_ENABLE              (1 << BAUDCON_RC9)
#define BAUDCON_RC9_DISABLE             (0 << BAUDCON_RC9)

#define BAUDCON_ENADD                    1
#define BAUDCON_ENADD_MSK               (1 << BAUDCON_ENADD)
#define BAUDCON_ENADD_ENABLE            (1 << BAUDCON_ENADD)
#define BAUDCON_ENADD_DISABLE           (0 << BAUDCON_ENADD)

#define BAUDCON_ENABD                    0
#define BAUDCON_ENABD_MSK               (1 << BAUDCON_ENABD)
#define BAUDCON_ENABD_ENABLE            (1 << BAUDCON_ENABD)
#define BAUDCON_ENABD_DISABLE           (0 << BAUDCON_ENABD)

// BRGRH //BRGRH[7:0]
// BRGRL //BRGRL[7:0]
// TXREG //TXREG[7:0]
// RCREG //RCREG[7:0]

/**************************************************************************************************|
|*                                      Function Level                                            *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function-like Macro:                                                                            |
|    Register Bits field Configuration without function call overhead,                             |
|    user should take care of detail of h/w behavior and constrains.                               |
|-------------------------------------------------------------------------------------------------*/
#define UART_INT_TXEnable()             (INTE2 |= INTE2_TXIE_ENABLE)
#define UART_INT_TXIsEnable()           (INTE2 & INTE2_TXIE_ENABLE)
#define UART_INT_TXDisable()            (INTE2 &= (~INTE2_TXIE_MSK))
#define UART_INT_TXIsFlag()             (INTF2 & INTF2_TXIF_SET)
#define UART_INT_TXClearFlag()          (INTF2 &= (~INTF2_TXIF_MSK))
#define UART_INT_RCEnable()             (INTE2 |= INTE2_RCIE_ENABLE)
#define UART_INT_RCDisable()            (INTE2 &= (~INTE2_RCIE_MSK))
#define UART_INT_RCIsFlag()             (INTF2 & INTF2_RCIF_SET)
#define UART_INT_RCClearFlag()          (INTF2 &= (~INTF2_RCIF_MSK))

#define UART_Enable()                   (URCON |= URCON_ENSP_ENABLE)
#define UART_Disable()                  (URCON &= (~URCON_ENSP_MSK))
#define UART_TXEnable()                 (URCON |= URCON_ENTX_ENABLE)
#define UART_TXDisable()                (URCON &= (~URCON_ENTX_MSK))
#define UART_TX9Enable()                (URCON |= URCON_TX9_ENABLE)
#define UART_TX9Disable()               (URCON &= (~URCON_TX9_MSK))
#define UART_WakeUpEnable()             (URCON |= URCON_WUE_ENABLE)
#define UART_WakeUpDisable()            (URCON &= (~URCON_WUE_MSK))
#define UART_DataReceiveEnable()        (BAUDCON |= BAUDCON_ENCR_ENABLE)
#define UART_DataReceiveDisable()       (BAUDCON &= (~BAUDCON_ENCR_MSK))
#define UART_RC9Enable()                (BAUDCON |= BAUDCON_RC9_ENABLE)
#define UART_RC9Disable()               (BAUDCON &= (~BAUDCON_RC9_MSK))
#define UART_AddrDetectionEnable()      (BAUDCON |= BAUDCON_ENADD_ENABLE)
#define UART_AddrDetectionDisable()     (BAUDCON &= (~BAUDCON_ENADD_MSK))
#define UART_AutoBaudEnable()           (BAUDCON |= BAUDCON_ENABD_ENABLE)
#define UART_AutoBaudDisable()          (BAUDCON &= (~BAUDCON_ENABD_MSK))

#define UART_TXData9(TX9DSel)           (URCON = ((URCON & (~URCON_TX9D_MSK)) | TX9DSel))
#define UART_ParityCheck(PARSel)        (URCON = ((URCON & (~URCON_PARITY_MSK)) | PARSel))
#define UART_RCData9()                  (URSTA&URSTA_RC9D_MSK)//modify :20170720 //(URSTA = ((URSTA & (~URSTA_RC9D_MSK)) | RC9DSel))

#define UART_PERRIsFlag()               (URSTA & URSTA_PERR_ERROR)
#define UART_OERRIsFlag()               (URSTA & URSTA_OERR_HAPPENED)
#define UART_FERRIsFlag()               (URSTA & URSTA_FERR_INCOMPLETE)
#define UART_RCIDLIsFlag()              (URSTA & URSTA_RCIDL_RECEIVING)
#define UART_TRMTIsFlag()               (URSTA & URSTA_TRMT_EMPTY)
#define UART_ABDOVFIsFlag()             (URSTA & URSTA_ABDOVF_HAPPENED)

/*-------------------------------------------------------------------------------------------------|
|  Function call:                                                                                  |
|    For general and functional register access.                                                   |
|-------------------------------------------------------------------------------------------------*/
void UART_Open(unsigned int  uBRGR,
               unsigned char uDataBits,
               unsigned char uParity);
void UART_AutoBaudrateEnable(void);
