/**************************************************************************************************|
|* Copyright 2016 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|* - Generic Peripheral Library: A general and functional Interface for the specific Peripheral   *|
|* - Low Level Peripheral Access: Register-Bits Level access Macro, user must take care           *|
|*   of calling procedure and hardware constraints                                                *|
|* - Support Target: HY11P Series                                                                 *|
|**************************************************************************************************/
#include <INT.h>           // Interrupt Config for WDT

/**************************************************************************************************|
|*                               Peripheral Register Bits field                                   *|
|**************************************************************************************************/
// TMACN //
#define TMACN_ENWDT                      3
#define TMACN_ENWDT_MSK                 (1 << TMACN_ENWDT)
#define TMACN_ENWDT_ENABLE              (1 << TMACN_ENWDT)
#define TMACN_ENWDT_DISABLE             (0 << TMACN_ENWDT)

#define TMACN_WDTS                       0
#define TMACN_WDTS_MSK                  (7 << TMACN_WDTS)
#define TMACN_WDTS_32768                (7 << TMACN_WDTS)
#define TMACN_WDTS_8192                 (6 << TMACN_WDTS)
#define TMACN_WDTS_2048                 (5 << TMACN_WDTS)
#define TMACN_WDTS_512                  (4 << TMACN_WDTS)
#define TMACN_WDTS_128                  (3 << TMACN_WDTS)
#define TMACN_WDTS_32                   (2 << TMACN_WDTS)
#define TMACN_WDTS_8                    (1 << TMACN_WDTS)
#define TMACN_WDTS_2                    (0 << TMACN_WDTS)

/**************************************************************************************************|
|*                                      Function Level                                            *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function-like Macro:                                                                            |
|    Register Bits field Configuration without function call overhead,                             |
|    user should take care of detail of h/w behavior and constrains.                               |
|-------------------------------------------------------------------------------------------------*/
#define WDT_INT_Enable()                (INTE1 |= INTE1_WDTIE_ENABLE)
#define WDT_INT_Disable()               (INTE1 &= (~INTE1_WDTIE_MSK))
#define WDT_INT_IsFlag()                (INTF1 & INTF1_WDTIF_SET)
#define WDT_INT_ClearFlag()             (INTF1 &= (~INTF1_WDTIF_MSK))

#define WDT_Enable()                    (TMACN |= TMACN_ENWDT_ENABLE)
#define WDT_OFTimeSel(WDTSel)           (TMACN = ((TMACN & (~TMACN_WDTS_MSK)) | WDTSel))
#define WDT_Clear()                     __asm__ ("CWDT")  //Clear WDT counter

/*-------------------------------------------------------------------------------------------------|
|  Function call:                                                                                  |
|    For general and functional register access.                                                   |
|-------------------------------------------------------------------------------------------------*/
void WDT_Open(unsigned char wdts);      //Configure WDT overflow time
